@@ -27,12 +27,13 @@ Afrikaan_LO_Latest_full
    <eu>Afrikaans Language Meta-Package for LibreOffice</eu>
    <fa>Afrikaans Language Meta-Package for LibreOffice</fa>
    <fil_PH>Afrikaans Language Meta-Package for LibreOffice</fil_PH>
-   <fi>Afrikaaninen kielipaketti LibreOffice:lle</fi>
+   <fi>Afrikaansin kielipaketti LibreOffice:lle</fi>
    <fr_BE>Méta-Paquet de langue afrikanns pour LibreOffice</fr_BE>
    <fr>Méta-Paquet de langue afrikanns pour LibreOffice</fr>
    <gl_ES>Africánder meta-paquete de idioma para LiberOffice</gl_ES>
+   <gu>Afrikaans Language Meta-Package for LibreOffice</gu>
    <he_IL>חבילת על לשפת אפריקאנס עבור LibreOffice</he_IL>
-   <hi>Afrikaans Language Meta-Package for LibreOffice</hi>
+   <hi>लिब्रे-ऑफिस हेतु अफ़्रीकी डच भाषा मेटा-पैकेज</hi>
    <hr>Afrikaans Language Meta-Package for LibreOffice</hr>
    <hu>Afrikaans Language Meta-Package for LibreOffice</hu>
    <id>Afrikaans Language Meta-Package for LibreOffice</id>
@@ -50,12 +51,12 @@ Afrikaan_LO_Latest_full
    <nl>Afrikaans Taal Meta-Pakket voor LibreOffice</nl>
    <pl>Meta-pakiet języka Afrikaans dla LibreOffice</pl>
    <pt_BR>Africâner Pacote de Idioma para o LibreOffice</pt_BR>
-   <pt>Africander Meta-Pacote de Idioma para LibreOffice</pt>
+   <pt>Meta-Pacote de Idioma Africander para o LibreOffice</pt>
    <ro>Afrikaans Language Meta-Package for LibreOffice</ro>
    <ru>Afrikaans Language Meta-Package for LibreOffice</ru>
    <sk>Afrikaans Language Meta-Package for LibreOffice</sk>
    <sl>Afrikaan jezikovni meta-paket za LibreOffice</sl>
-   <sq>Afrikaans Language Meta-Package for LibreOffice</sq>
+   <sq>Meta-Paketë gjuhësore për LibreOffice-in në afrikaans</sq>
    <sr>Afrikaans Language Meta-Package for LibreOffice</sr>
    <sv>Afrikaans Språk Meta-Paket för LibreOffice</sv>
    <th>Meta-Package ภาษา Afrikaans สำหรับ LibreOffice</th>
