@@ -27,17 +27,18 @@ Afrikaan_Firefox
    <eu>Afrikaan localisation of Firefox</eu>
    <fa>Afrikaan localisation of Firefox</fa>
    <fil_PH>Afrikaan localisation of Firefox</fil_PH>
-   <fi>Afrikaaninen Firefox-kotoistus</fi>
+   <fi>Afrikaansin kielinen Firefox kielipaketti</fi>
    <fr_BE>Localisation en afrikaans pour Firefox</fr_BE>
    <fr>Localisation en afrikaans pour Firefox</fr>
    <gl_ES>Localización de Firefox a africánder</gl_ES>
+   <gu>Afrikaan localisation of Firefox</gu>
    <he_IL>תרגומי Firefox לאפריקאנס</he_IL>
-   <hi>Afrikaan localisation of Firefox</hi>
+   <hi>फायरफॉक्स का अफ़्रीकी डच अनुवाद</hi>
    <hr>Afrikaanska lokalizacija Firefoxa</hr>
    <hu>Afrikaan localisation of Firefox</hu>
    <id>Afrikaan localisation of Firefox</id>
    <is>Afrikaan localisation of Firefox</is>
-   <it>Localizzazione in Afrikaans di Firefox</it>
+   <it>Localizzazione in afrikaans di Firefox</it>
    <ja>Firefox のアフリカーンス語版</ja>
    <kk>Afrikaan localisation of Firefox</kk>
    <ko>Afrikaan localisation of Firefox</ko>
@@ -55,7 +56,7 @@ Afrikaan_Firefox
    <ru>Африканская локализация Firefox</ru>
    <sk>Afrikaan lokalizácia pre Firefox</sk>
    <sl>Afrikaan localisation of Firefox</sl>
-   <sq>Afrikaan localisation of Firefox</sq>
+   <sq>Përkthimi i Firefox-it në afrikaans</sq>
    <sr>Afrikaan localisation of Firefox</sr>
    <sv>Afrikaan lokalisering av Firefox</sv>
    <th>Afrikaan localisation ของ Firefox</th>
