@@ -31,8 +31,9 @@ Amharic_LO_Latest_full
    <fr_BE>Méta-Paquet de langue amharique pour LibreOffice</fr_BE>
    <fr>Méta-Paquet de langue amharique pour LibreOffice</fr>
    <gl_ES>Amárico Meta-paquete de idioma para LibreOffice</gl_ES>
+   <gu>Amharic Language Meta-Package for LibreOffice</gu>
    <he_IL>חבילת על לאמהרית עבור LibreOffice</he_IL>
-   <hi>Amharic Language Meta-Package for LibreOffice</hi>
+   <hi>लिब्रे-ऑफिस हेतु अम्हारिक भाषा मेटा-पैकेज</hi>
    <hr>Amharic Language Meta-Package for LibreOffice</hr>
    <hu>Amharic Language Meta-Package for LibreOffice</hu>
    <id>Amharic Language Meta-Package for LibreOffice</id>
@@ -55,7 +56,7 @@ Amharic_LO_Latest_full
    <ru>Amharic Language Meta-Package for LibreOffice</ru>
    <sk>Amharic Language Meta-Package for LibreOffice</sk>
    <sl>Amharični jezikovni meta-paket za LibreOffice</sl>
-   <sq>Amharic Language Meta-Package for LibreOffice</sq>
+   <sq>Meta-Paketë gjuhësore për LibreOffice-in në amharisht</sq>
    <sr>Amharic Language Meta-Package for LibreOffice</sr>
    <sv>Amhariskt Språk Meta-Paket för LibreOffice</sv>
    <th>Meta-Package ภาษา Amharic สำหรับ LibreOffice</th>
