@@ -42,7 +42,6 @@ Assamese_LO_Latest_full
    <ja>LibreOffice用のアッサム語メタパッケージ</ja>
    <kk>Assamese Language Meta-Package for LibreOffice</kk>
    <ko>Assamese Language Meta-Package for LibreOffice</ko>
-   <ku>Assamese Language Meta-Package for LibreOffice</ku>
    <lt>Assamese Language Meta-Package for LibreOffice</lt>
    <mk>Assamese Language Meta-Package for LibreOffice</mk>
    <mr>Assamese Language Meta-Package for LibreOffice</mr>
@@ -50,7 +49,6 @@ Assamese_LO_Latest_full
    <nb>Assamesisk språkpakke for LibreOffice</nb>
    <nl_BE>Assamese Language Meta-Package for LibreOffice</nl_BE>
    <nl>Assamese Taal Meta-Pakket voor LibreOffice​</nl>
-   <or>Assamese Language Meta-Package for LibreOffice</or>
    <pl>Meta-pakiet języka Assamese dla LibreOffice</pl>
    <pt_BR>Assamês Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Assamês Meta-Pacote de Idioma para LibreOffice</pt>
@@ -58,7 +56,6 @@ Assamese_LO_Latest_full
    <ru>Assamese Language Meta-Package for LibreOffice</ru>
    <sk>Assamese Language Meta-Package for LibreOffice</sk>
    <sl>Asameški jezikovni meta-paket za LibreOffice</sl>
-   <so>Assamese Language Meta-Package for LibreOffice</so>
    <sq>Meta-Paketë gjuhësore për LibreOffice-in në asamisht</sq>
    <sr>Assamese Language Meta-Package for LibreOffice</sr>
    <sv>Assamesiskt Språk Meta-Paket för LibreOffice</sv>
