@@ -42,7 +42,6 @@ Basque_LO_Latest_full
    <ja>LibreOffice 用のバスク語メタパッケージ</ja>
    <kk>Basque Language Meta-Package for LibreOffice</kk>
    <ko>Basque Language Meta-Package for LibreOffice</ko>
-   <ku>Basque Language Meta-Package for LibreOffice</ku>
    <lt>Basque Language Meta-Package for LibreOffice</lt>
    <mk>Basque Language Meta-Package for LibreOffice</mk>
    <mr>Basque Language Meta-Package for LibreOffice</mr>
@@ -50,7 +49,6 @@ Basque_LO_Latest_full
    <nb>Baskisk språkpakke for LibreOffice</nb>
    <nl_BE>Basque Language Meta-Package for LibreOffice</nl_BE>
    <nl>Baskisch Taal Meta-Pakket voor LibreOffice​</nl>
-   <or>Basque Language Meta-Package for LibreOffice</or>
    <pl>Meta-pakiet języka baskijskiego dla LibreOffice</pl>
    <pt_BR>Basco Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Basco Meta-Pacote de Idioma para LibreOffice</pt>
@@ -58,7 +56,6 @@ Basque_LO_Latest_full
    <ru>Basque Language Meta-Package for LibreOffice</ru>
    <sk>Basque Language Meta-Package for LibreOffice</sk>
    <sl>Baskovski jezikovni meta-paket za LibreOffice</sl>
-   <so>Basque Language Meta-Package for LibreOffice</so>
    <sq>Meta-Paketë gjuhësore për LibreOffice-in në baskisht</sq>
    <sr>Basque Language Meta-Package for LibreOffice</sr>
    <sv>Baskiskt Språk Meta-Paket för LibreOffice</sv>
@@ -92,7 +89,6 @@ libreoffice-writer
 libreoffice-base
 libreoffice-gtk3
 libreoffice-l10n-eu
-libreoffice-java-common
 
 </install_package_names>
 
@@ -108,7 +104,6 @@ libreoffice-draw
 libreoffice-impress
 libreoffice-math
 libreoffice-writer
-libreoffice-java-common
 libreoffice-base
 libreoffice-gtk3
 libreoffice-l10n-eu
