@@ -31,8 +31,9 @@ Basque_Thunderbird
    <fr_BE>Localisation en basque pour Thunderbird</fr_BE>
    <fr>Localisation en basque pour Thunderbird</fr>
    <gl_ES>Localización de Thunderbird para basco</gl_ES>
+   <gu>Basque localisation of Thunderbird</gu>
    <he_IL>Basque localisation of Thunderbird</he_IL>
-   <hi>Basque localisation of Thunderbird</hi>
+   <hi>थंडरबर्ड का बास्क संस्करण</hi>
    <hr>Baskijska lokalizacija Thunderbirda</hr>
    <hu>Basque localisation of Thunderbird</hu>
    <id>Basque localisation of Thunderbird</id>
@@ -55,11 +56,11 @@ Basque_Thunderbird
    <ru>Basque localisation of Thunderbird</ru>
    <sk>Basque lokalizácia pre Thunderbird</sk>
    <sl>Basque localisation of Thunderbird</sl>
-   <sq>Basque localisation of Thunderbird</sq>
+   <sq>Përkthimi i Thunderbird-it në baskisht</sq>
    <sr>Basque localisation of Thunderbird</sr>
    <sv>Baskisk lokalisering av Thunderbird</sv>
    <th>Basque localisation ของ Thunderbird</th>
-   <tr>Thunderbird'ün Bask dili yerelleştirmesi</tr>
+   <tr>Thunderbird Bask dili yerelleştirmesi</tr>
    <uk>Basque локалізація Thunderbird</uk>
    <vi>Basque localisation of Thunderbird</vi>
    <zh_CN>Thunderbird 巴斯克语语言包</zh_CN>
