@@ -15,7 +15,7 @@ Belarusian_Firefox
    <be>Belarusian localisation of Firefox</be>
    <bg>Belarusian localisation of Firefox</bg>
    <bn>Belarusian localisation of Firefox</bn>
-   <ca>Localització de Firefox en Belarus</ca>
+   <ca>Localització de Firefox en Bielorús</ca>
    <cs>Belarusian localisation of Firefox</cs>
    <da>Hviderussisk oversættelse af Firefox</da>
    <de>Weißrussische Lokalisierung von Firefox</de>
@@ -28,7 +28,7 @@ Belarusian_Firefox
    <fa>Belarusian localisation of Firefox</fa>
    <fil_PH>Belarusian localisation of Firefox</fil_PH>
    <fi>Valko-venäläinen Firefox-kotoistus</fi>
-   <fr_BE>Belarusian localisation of Firefox</fr_BE>
+   <fr_BE>Localisation en biélorusse pour Firefox</fr_BE>
    <fr>Localisation en biélorusse pour Firefox</fr>
    <gl_ES>Localización de Firefox en beloruso</gl_ES>
    <gu>Belarusian localisation of Firefox</gu>
@@ -56,7 +56,7 @@ Belarusian_Firefox
    <ru>Белорусская локализация Firefox</ru>
    <sk>Bieloruská lokalizácia pre Firefox</sk>
    <sl>Belarusian localisation of Firefox</sl>
-   <sq>Belarusian localisation of Firefox</sq>
+   <sq>Përkthimi i Firefox-it në bjellorusisht</sq>
    <sr>Belarusian localisation of Firefox</sr>
    <sv>Belarus lokalisering av Firefox</sv>
    <th>Belarusian localisation ของ Firefox</th>
