@@ -28,12 +28,12 @@ Chinese_Input_fcitx
    <fa>Chinese fcitx</fa>
    <fil_PH>Chinese fcitx</fil_PH>
    <fi>Kiinalainen fctx</fi>
-   <fr_BE>Chinese fcitx</fr_BE>
+   <fr_BE>Chinois fcitx</fr_BE>
    <fr>Chinois fcitx</fr>
    <gl_ES>Chinés fcitx</gl_ES>
    <gu>Chinese fcitx</gu>
    <he_IL>Chinese fcitx</he_IL>
-   <hi>Chinese fcitx</hi>
+   <hi>चीनी fcitx</hi>
    <hr>Chinese fcitx</hr>
    <hu>Chinese fcitx</hu>
    <id>Chinese fcitx</id>
@@ -55,8 +55,8 @@ Chinese_Input_fcitx
    <ro>Chinese fcitx</ro>
    <ru>Chinese fcitx</ru>
    <sk>Chinese fcitx</sk>
-   <sl>Chinese fcitx</sl>
-   <sq>Chinese fcitx</sq>
+   <sl>Kitajski fcitx</sl>
+   <sq>fcitx për kinezçen</sq>
    <sr>Chinese fcitx</sr>
    <sv>Kinesisk fcitx</sv>
    <th>fcitx ภาษาจีน</th>
