@@ -28,7 +28,7 @@ Croatian_Thunderbird
    <fa>Croatian localisation of thunderbird</fa>
    <fil_PH>Croatian localisation of thunderbird</fil_PH>
    <fi>Kroatialainen Thunderbird-kotoistus</fi>
-   <fr_BE>Croatian localisation of thunderbird</fr_BE>
+   <fr_BE>Localisation en croate pour Thunderbird</fr_BE>
    <fr>Localisation en croate pour Thunderbird</fr>
    <gl_ES>Localización de Thunderbird para croata</gl_ES>
    <gu>Croatian localisation of thunderbird</gu>
@@ -55,8 +55,8 @@ Croatian_Thunderbird
    <ro>Croatian localisation of thunderbird</ro>
    <ru>Croatian localisation of thunderbird</ru>
    <sk>Croatian localisation of thunderbird</sk>
-   <sl>Croatian localisation of thunderbird</sl>
-   <sq>Croatian localisation of thunderbird</sq>
+   <sl>Hrvaške krajevne nastavitve za thunderbird</sl>
+   <sq>Përkthimi i Thunderbird-it në kroatisht</sq>
    <sr>Croatian localisation of thunderbird</sr>
    <sv>Kroatisk lokalisering av thunderbird</sv>
    <th>Croatian localisation ของ Thunderbird</th>
