@@ -28,12 +28,12 @@ Czech_LO_Latest_full
    <fa>Czech LibreOffice Language Meta-Package</fa>
    <fil_PH>Czech LibreOffice Language Meta-Package</fil_PH>
    <fi>Tsekkiläinen metatieto-paketti LibreOffice:lle</fi>
-   <fr_BE>Czech LibreOffice Language Meta-Package</fr_BE>
+   <fr_BE>Méta-Paquet langue tchèque pour LibreOffice</fr_BE>
    <fr>Méta-Paquet langue tchèque pour LibreOffice</fr>
    <gl_ES>Checo Meta-paquete de Idioma para LibreOffice</gl_ES>
    <gu>Czech LibreOffice Language Meta-Package</gu>
    <he_IL>Czech LibreOffice Language Meta-Package</he_IL>
-   <hi>Czech LibreOffice Language Meta-Package</hi>
+   <hi>लिब्रे-ऑफिस हेतु चेक भाषा मेटा-पैकेज</hi>
    <hr>Czech LibreOffice Language Meta-Package</hr>
    <hu>Czech LibreOffice Language Meta-Package</hu>
    <id>Czech LibreOffice Language Meta-Package</id>
@@ -55,8 +55,8 @@ Czech_LO_Latest_full
    <ro>Czech LibreOffice Language Meta-Package</ro>
    <ru>Czech LibreOffice Language Meta-Package</ru>
    <sk>Czech LibreOffice Language Meta-Package</sk>
-   <sl>Czech LibreOffice Language Meta-Package</sl>
-   <sq>Czech LibreOffice Language Meta-Package</sq>
+   <sl>Češki jezikovni metapaket za LibreOffice</sl>
+   <sq>Meta-Paketë gjuhësore për LibreOffice-in në çekisht</sq>
    <sr>Czech LibreOffice Language Meta-Package</sr>
    <sv>Tjeckisk LibreOffice Språk Meta-Paket</sv>
    <th>Meta-Package ภาษา Czech สำหรับ LibreOffice</th>
