@@ -15,14 +15,14 @@ Kernel-Debian_32bit_PAE
    <be>Fallback Debian 4.19 32bit PAE linux kernel</be>
    <bg>Fallback Debian 4.19 32bit PAE linux kernel</bg>
    <bn>Fallback Debian 4.19 32bit PAE linux kernel</bn>
-   <ca>Fallback Debian 4.19 32bit PAE linux kernel</ca>
+   <ca>Kernel linux Debian 4.19 32bit PAE Fallback</ca>
    <cs>Fallback Debian 4.19 32bit PAE linux kernel</cs>
    <da>Fallback Debian 4.19 32bit PAE linux kernel</da>
-   <de>Ausweich-Kernel: Debian-Linux 4.19 32bit PAE</de>
+   <de>Fallback Debian 4.19 32bit PAE linux kernel</de>
    <el>Debian 4.19 32bit linux kernel PAE</el>
    <en>Fallback Debian 4.19 32bit PAE linux kernel</en>
-   <es_ES>Fallback Debian 4.19 32bit PAE linux kernel</es_ES>
-   <es>Kernel/nucleo linux 4.19 32 bits PAE de Debian (respaldo)</es>
+   <es_ES>Kernel Linux alternativo Debian 4.19 32bit PAE</es_ES>
+   <es>Kernel Linux alternativo Debian 4.19 32bit PAE</es>
    <et>Fallback Debian 4.19 32bit PAE linux kernel</et>
    <eu>Fallback Debian 4.19 32bit PAE linux kernel</eu>
    <fa>Fallback Debian 4.19 32bit PAE linux kernel</fa>
@@ -31,14 +31,15 @@ Kernel-Debian_32bit_PAE
    <fr_BE>Noyau linux Fallback Debian 4.19 32bit PAE</fr_BE>
    <fr>Noyau linux Fallback Debian 4.19 32bit PAE</fr>
    <gl_ES>Fallback Debian 4.19 32bit PAE linux kernel</gl_ES>
+   <gu>Fallback Debian 4.19 32bit PAE linux kernel</gu>
    <he_IL>Fallback Debian 4.19 32bit PAE linux kernel</he_IL>
    <hi>Fallback Debian 4.19 32bit PAE linux kernel</hi>
    <hr>Fallback Debian 4.19 32bit PAE linux kernel</hr>
    <hu>Fallback Debian 4.19 32bit PAE linux kernel</hu>
    <id>Fallback Debian 4.19 32bit PAE linux kernel</id>
    <is>Fallback Debian 4.19 32bit PAE linux kernel</is>
-   <it>Fallback Debian 4.19 32bit PAE linux kernel</it>
-   <ja>Debian 4.19 32bit PAE linux kernel フォールバック</ja>
+   <it>Kernel Linux Debian Fallback 4.19 32bit PAE</it>
+   <ja>Fallback Debian 4.19 32bit PAE linux kernel</ja>
    <kk>Fallback Debian 4.19 32bit PAE linux kernel</kk>
    <ko>Fallback Debian 4.19 32bit PAE linux kernel</ko>
    <lt>Fallback Debian 4.19 32bit PAE linux kernel</lt>
@@ -49,15 +50,15 @@ Kernel-Debian_32bit_PAE
    <nl_BE>Fallback Debian 4.19 32bit PAE linux kernel</nl_BE>
    <nl>Fallback Debian 4.19 32bit PAE linux kernel</nl>
    <pl>Fallback Debian 4.19 32bit PAE linux kernel</pl>
-   <pt_BR>Fallback Debian 4.19 32bit PAE linux kernel</pt_BR>
-   <pt>Fallback Debian 4.19 32bit PAE linux kernel</pt>
+   <pt_BR>Fallback do Debian 4.19 de 32 bits PAE linux kernel</pt_BR>
+   <pt>Núcleo (Kernel) linux Debian 4.19 32bit PAE de reserva</pt>
    <ro>Fallback Debian 4.19 32bit PAE linux kernel</ro>
    <ru>Fallback Debian 4.19 32bit PAE linux kernel</ru>
    <sk>Fallback Debian 4.19 32bit PAE linux kernel</sk>
    <sl>Fallback Debian 4.19 32bit PAE linux kernel</sl>
    <sq>Fallback Debian 4.19 32bit PAE linux kernel</sq>
    <sr>Fallback Debian 4.19 32bit PAE linux kernel</sr>
-   <sv>Fallback Debian 4.19 32bit PAE linux kernel</sv>
+   <sv>Fallback Debian 4.19 32bit PAE linux-kärna</sv>
    <th>Fallback Debian 4.19 32bit PAE linux kernel</th>
    <tr>Fallback Debian 4.19 32bit PAE linux kernel</tr>
    <uk>Fallback Debian 4.19 32bit PAE linux kernel</uk>
@@ -78,8 +79,8 @@ Kernel-Debian_32bit_PAE
 </preinstall>
 
 <install_package_names>
-linux-image-4.19.0-14-686-pae
-linux-headers-4.19.0-14-686-pae
+linux-image-4.19.0-17-686-pae
+linux-headers-4.19.0-17-686-pae
 </install_package_names>
 
 <postinstall>
@@ -87,8 +88,8 @@ linux-headers-4.19.0-14-686-pae
 </postinstall>
 
 <uninstall_package_names>
-linux-image-4.19.0-14-686-pae
-linux-headers-4.19.0-14-686-pae
+linux-image-4.19.0-17-686-pae
+linux-headers-4.19.0-17-686-pae
 </uninstall_package_names>
 
 </app>
