@@ -15,7 +15,7 @@ Dutch
    <be>Dutch dictionary for hunspell</be>
    <bg>Dutch dictionary for hunspell</bg>
    <bn>Dutch dictionary for hunspell</bn>
-   <ca>Dutch dictionary for hunspell</ca>
+   <ca>Diccionari holandès per a hunspell</ca>
    <cs>Dutch dictionary for hunspell</cs>
    <da>Dutch dictionary for hunspell</da>
    <de>Niederländisches Wörterbuch für “Hunspell”</de>
@@ -28,12 +28,12 @@ Dutch
    <fa>Dutch dictionary for hunspell</fa>
    <fil_PH>Dutch dictionary for hunspell</fil_PH>
    <fi>Dutch dictionary for hunspell</fi>
-   <fr_BE>Dutch dictionary for hunspell</fr_BE>
+   <fr_BE>Néerlandais dictionnaire pour hunspell</fr_BE>
    <fr>Néerlandais dictionnaire pour hunspell</fr>
    <gl_ES>Dutch dictionary for hunspell</gl_ES>
    <gu>Dutch dictionary for hunspell</gu>
    <he_IL>Dutch dictionary for hunspell</he_IL>
-   <hi>Dutch dictionary for hunspell</hi>
+   <hi>Hunspell हेतु डच शब्दकोष</hi>
    <hr>Dutch dictionary for hunspell</hr>
    <hu>Dutch dictionary for hunspell</hu>
    <id>Dutch dictionary for hunspell</id>
@@ -55,8 +55,8 @@ Dutch
    <ro>Dutch dictionary for hunspell</ro>
    <ru>Dutch dictionary for hunspell</ru>
    <sk>Dutch dictionary for hunspell</sk>
-   <sl>Dutch dictionary for hunspell</sl>
-   <sq>Dutch dictionary for hunspell</sq>
+   <sl>Nizozemski slovar za hunspell</sl>
+   <sq>Fjalor holandisht për hunspell</sq>
    <sr>Dutch dictionary for hunspell</sr>
    <sv>Holländsk ordbok för hunspell</sv>
    <th>Dutch dictionary for hunspell</th>
