@@ -31,8 +31,9 @@ Dutch_LO_Latest_full
    <fr_BE>Méta-Paquet langue néerlandaise pour LibreOffice</fr_BE>
    <fr>Méta-Paquet langue néerlandaise pour LibreOffice</fr>
    <gl_ES>Neerlandés Meta-paquete de Idioma para LibreOffice</gl_ES>
+   <gu>Dutch LibreOffice Language Meta-Package</gu>
    <he_IL>Dutch LibreOffice Language Meta-Package</he_IL>
-   <hi>Dutch LibreOffice Language Meta-Package</hi>
+   <hi>लिब्रे-ऑफिस हेतु डच भाषा मेटा-पैकेज</hi>
    <hr>Dutch LibreOffice Language Meta-Package</hr>
    <hu>Dutch LibreOffice Language Meta-Package</hu>
    <id>Dutch LibreOffice Language Meta-Package</id>
@@ -55,7 +56,7 @@ Dutch_LO_Latest_full
    <ru>Dutch LibreOffice Language Meta-Package</ru>
    <sk>Dutch LibreOffice Language Meta-Package</sk>
    <sl>Dutch LibreOffice Language Meta-Package</sl>
-   <sq>Dutch LibreOffice Language Meta-Package</sq>
+   <sq>Meta-Paketë gjuhësore për LibreOffice-in në holandisht</sq>
    <sr>Dutch LibreOffice Language Meta-Package</sr>
    <sv>Holländska LibreOffice Språk Meta-Paket</sv>
    <th>Meta-Package ภาษา Dutch สำหรับ LibreOffice</th>
