@@ -42,15 +42,13 @@ English (GB)
    <ja>Hunspell 用英語（イギリス）辞書</ja>
    <kk>English (GB) dictionary for hunspell</kk>
    <ko>English (GB) dictionary for hunspell</ko>
-   <ku>English (GB) dictionary for hunspell</ku>
    <lt>English (GB) dictionary for hunspell</lt>
    <mk>English (GB) dictionary for hunspell</mk>
    <mr>English (GB) dictionary for hunspell</mr>
    <nb_NO>English (GB) dictionary for hunspell</nb_NO>
    <nb>Engelsk (britisk) ordliste for hunspell</nb>
    <nl_BE>English (GB) dictionary for hunspell</nl_BE>
-   <nl>Engels (GB) woordenboek voor hunspell</nl>
-   <or>English (GB) dictionary for hunspell</or>
+   <nl>English (GB) dictionary for hunspell</nl>
    <pl>English (GB) dictionary for hunspell</pl>
    <pt_BR>Dicionário Inglês da Grã-Bretanha para o hunspell (corretor ortográfico e analisador morfológico)</pt_BR>
    <pt>Dicionário Inglês (GB) para hunspell</pt>
@@ -58,7 +56,6 @@ English (GB)
    <ru>English (GB) dictionary for hunspell</ru>
    <sk>English (GB) dictionary for hunspell</sk>
    <sl>Angleški (VB) slovar za hunspell</sl>
-   <so>English (GB) dictionary for hunspell</so>
    <sq>Fjalor anglisht (Britani e Madhe) për hunspell</sq>
    <sr>English (GB) dictionary for hunspell</sr>
    <sv>Engelsk (GB) ordbok för hunspell</sv>
