@@ -15,29 +15,30 @@ Esperanto_Default_Firefox_esr
    <be>Esperanto localisation of Firefox ESR</be>
    <bg>Esperanto localisation of Firefox ESR</bg>
    <bn>Esperanto localisation of Firefox ESR</bn>
-   <ca>Esperanto localisation of Firefox ESR</ca>
+   <ca>Localització de Firefox-ESR en Esperanto</ca>
    <cs>Esperanto localisation of Firefox ESR</cs>
    <da>Esperanto localisation of Firefox ESR</da>
    <de>Lokalisation für “Esperanto” von “Firefox ESR”</de>
    <el>Esperanto για Firefox ESR</el>
    <en>Esperanto localisation of Firefox ESR</en>
-   <es_ES>Esperanto localisation of Firefox ESR</es_ES>
+   <es_ES>Localización Esperanto de Firefox ESR</es_ES>
    <es>Localización Esperanto de Firefox ESR</es>
    <et>Esperanto localisation of Firefox ESR</et>
    <eu>Esperanto localisation of Firefox ESR</eu>
    <fa>Esperanto localisation of Firefox ESR</fa>
    <fil_PH>Esperanto localisation of Firefox ESR</fil_PH>
    <fi>Esperanto localisation of Firefox ESR</fi>
-   <fr_BE>Localisation en espéranto de Firefox ESR</fr_BE>
-   <fr>Localisation en espéranto de Firefox ESR</fr>
+   <fr_BE>Localisation en espéranto pour Firefox ESR</fr_BE>
+   <fr>Localisation en espéranto pour Firefox ESR</fr>
    <gl_ES>Esperanto localisation of Firefox ESR</gl_ES>
+   <gu>Esperanto localisation of Firefox ESR</gu>
    <he_IL>Esperanto localisation of Firefox ESR</he_IL>
-   <hi>Esperanto localisation of Firefox ESR</hi>
+   <hi>फायरफॉक्स ईएसआर का एस्पेरांतो संस्करण</hi>
    <hr>Esperanto localisation of Firefox ESR</hr>
    <hu>Esperanto localisation of Firefox ESR</hu>
    <id>Esperanto localisation of Firefox ESR</id>
    <is>Esperanto localisation of Firefox ESR</is>
-   <it>Esperanto localisation of Firefox ESR</it>
+   <it>Localizzazione in esperanto di Firefox ESR</it>
    <ja>エスペラント語版 Firefox ESR</ja>
    <kk>Esperanto localisation of Firefox ESR</kk>
    <ko>Esperanto localisation of Firefox ESR</ko>
@@ -50,16 +51,16 @@ Esperanto_Default_Firefox_esr
    <nl>Esperanto localisation of Firefox ESR</nl>
    <pl>Esperanto localisation of Firefox ESR</pl>
    <pt_BR>Esperanto Localização para o Firefox ESR</pt_BR>
-   <pt>Esperanto localisation of Firefox ESR</pt>
+   <pt>Esperanto Localização para Firefox ESR</pt>
    <ro>Esperanto localisation of Firefox ESR</ro>
    <ru>Esperanto localisation of Firefox ESR</ru>
    <sk>Esperanto localisation of Firefox ESR</sk>
-   <sl>Esperanto localisation of Firefox ESR</sl>
-   <sq>Esperanto localisation of Firefox ESR</sq>
+   <sl>Esperanto krajevne nastavitve za Firefox ESR</sl>
+   <sq>Përkthimi i Firefox-it ESR në esperanto</sq>
    <sr>Esperanto localisation of Firefox ESR</sr>
    <sv>Esperanto lokalisering av Firefox ESR</sv>
    <th>Esperanto localisation of Firefox ESR</th>
-   <tr>Esperanto localisation of Firefox ESR</tr>
+   <tr>Firefox ESR Esperanto yerelleştirmesi</tr>
    <uk>Esperanto localisation of Firefox ESR</uk>
    <vi>Esperanto localisation of Firefox ESR</vi>
    <zh_CN>Esperanto localisation of Firefox ESR</zh_CN>
