@@ -5,13 +5,14 @@
 Language
 </category>
 
-<name>  
+<name>
 Estonian_LO_Latest_main
 </name>
 
-<description>  
+<description>
    <am>Estonian Language Meta-Package for LibreOffice</am>
    <ar>Estonian Language Meta-Package for LibreOffice</ar>
+   <be>Estonian Language Meta-Package for LibreOffice</be>
    <bg>Estonian Language Meta-Package for LibreOffice</bg>
    <bn>Estonian Language Meta-Package for LibreOffice</bn>
    <ca>Metapaquet d'idioma Estonià per LibreOffice</ca>
@@ -20,43 +21,50 @@ Estonian_LO_Latest_main
    <de>Estnisches Meta-Paket für LibreOffice</de>
    <el>LibreOffice στα Εσθονικά</el>
    <en>Estonian Language Meta-Package for LibreOffice</en>
-   <es>Meta-Paquete de idioma estonio para LibreOffice</es>
+   <es_ES>Meta-Paquete de idioma Estonio para LibreOffice</es_ES>
+   <es>Metapaquete de idioma Estonio para LibreOffice</es>
    <et>Estonian Language Meta-Package for LibreOffice</et>
    <eu>Estonian Language Meta-Package for LibreOffice</eu>
    <fa>Estonian Language Meta-Package for LibreOffice</fa>
    <fil_PH>Estonian Language Meta-Package for LibreOffice</fil_PH>
-   <fi>Estonian Language Meta-Package for LibreOffice</fi>
-   <fr>Estonian Language Meta-Package for LibreOffice</fr>
+   <fi>Eestiläinen kielipaketti LibreOffice:lle</fi>
+   <fr_BE>Méta-paquet de langue estonienne pour LibreOffice</fr_BE>
+   <fr>Méta-paquet de langue estonienne pour LibreOffice</fr>
+   <gl_ES>Estonio Meta-paquete de Idioma para LibreOffice</gl_ES>
+   <gu>Estonian Language Meta-Package for LibreOffice</gu>
    <he_IL>Estonian Language Meta-Package for LibreOffice</he_IL>
-   <hi>Estonian Language Meta-Package for LibreOffice</hi>
+   <hi>लिब्रे-ऑफिस हेतु एस्टोनियाई भाषा मेटा-पैकेज</hi>
    <hr>Estonian Language Meta-Package for LibreOffice</hr>
    <hu>Estonian Language Meta-Package for LibreOffice</hu>
    <id>Estonian Language Meta-Package for LibreOffice</id>
    <is>Estonian Language Meta-Package for LibreOffice</is>
    <it>Meta-pacchetto della lingua estone per LibreOffice</it>
-   <ja_JP>Estonian Language Meta-Package for LibreOffice</ja_JP>
-   <ja>Estonian Language Meta-Package for LibreOffice</ja>
+   <ja>LibreOffice用エストニア語メタパッケージ</ja>
    <kk>Estonian Language Meta-Package for LibreOffice</kk>
    <ko>Estonian Language Meta-Package for LibreOffice</ko>
    <lt>Estonian Language Meta-Package for LibreOffice</lt>
    <mk>Estonian Language Meta-Package for LibreOffice</mk>
    <mr>Estonian Language Meta-Package for LibreOffice</mr>
-   <nb>Estonian Language Meta-Package for LibreOffice</nb>
-   <nl>Estonian Language Meta-Package for LibreOffice</nl>
-   <pl>Estonian Language Meta-Package for LibreOffice</pl>
-   <pt_BR>Estonian Language Meta-Package for LibreOffice</pt_BR>
+   <nb_NO>Estonian Language Meta-Package for LibreOffice</nb_NO>
+   <nb>Estisk språkpakke for LibreOffice</nb>
+   <nl_BE>Estonian Language Meta-Package for LibreOffice</nl_BE>
+   <nl>Estoons Taal Meta-Pakket voor LibreOffice</nl>
+   <pl>Estoński meta-pakiet językowy dla LibreOffice</pl>
+   <pt_BR>Estónio Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Estónio Meta-Pacote de Idioma para LibreOffice</pt>
    <ro>Estonian Language Meta-Package for LibreOffice</ro>
    <ru>Estonian Language Meta-Package for LibreOffice</ru>
    <sk>Estonian Language Meta-Package for LibreOffice</sk>
    <sl>Estonski jezikovni meta-paket za LibreOffice</sl>
-   <sq>Estonian Language Meta-Package for LibreOffice</sq>
+   <sq>Meta-Paketë gjuhësore për LibreOffice-in në estonisht</sq>
    <sr>Estonian Language Meta-Package for LibreOffice</sr>
    <sv>Estniskt Språk Meta-Paket för LibreOffice</sv>
-   <tr>Estonian Language Meta-Package for LibreOffice</tr>
+   <th>Meta-Package ภาษา Estonian สำหรับ LibreOffice</th>
+   <tr>LibreOffice için Estonya Dili Üst-Paketi</tr>
    <uk>Estonian Language Meta-Package for LibreOffice</uk>
    <vi>Estonian Language Meta-Package for LibreOffice</vi>
-   <zh_CN>Estonian Language Meta-Package for LibreOffice</zh_CN>
+   <zh_CN>LibreOffice 爱沙尼亚语语言包</zh_CN>
+   <zh_HK>Estonian Language Meta-Package for LibreOffice</zh_HK>
    <zh_TW>Estonian Language Meta-Package for LibreOffice</zh_TW>
 </description>
 
