@@ -28,7 +28,7 @@ Estonian_Thunderbird
    <fa>Estonian localisation of Thunderbird</fa>
    <fil_PH>Estonian localisation of Thunderbird</fil_PH>
    <fi>Eestiläinen Thunderbird-kotoistus</fi>
-   <fr_BE>Estonian localisation of Thunderbird</fr_BE>
+   <fr_BE>Localisation en estonien pour Thunderbird</fr_BE>
    <fr>Localisation en estonien pour Thunderbird</fr>
    <gl_ES>Localización de Thunderbird ao estonio</gl_ES>
    <gu>Estonian localisation of Thunderbird</gu>
@@ -56,7 +56,7 @@ Estonian_Thunderbird
    <ru>Estonian localisation of Thunderbird</ru>
    <sk>Estonian localisation of Thunderbird</sk>
    <sl>Estonska lokalizacjja za Thunderbird</sl>
-   <sq>Estonian localisation of Thunderbird</sq>
+   <sq>Përkthimi i Thunderbird-it në estonisht</sq>
    <sr>Estonian localisation of Thunderbird</sr>
    <sv>Estnisk lokalisering av Thunderbird</sv>
    <th>Estonian localisation ของ Thunderbird</th>
