@@ -15,7 +15,7 @@ French_Default_Firefox_esr
    <be>French localisation of Firefox ESR</be>
    <bg>French localisation of Firefox ESR</bg>
    <bn>French localisation of Firefox ESR</bn>
-   <ca>French localisation of Firefox ESR</ca>
+   <ca>Localització de Firefox-ESR en Francès</ca>
    <cs>French localisation of Firefox ESR</cs>
    <da>French localisation of Firefox ESR</da>
    <de>Französische Lokalisation von “Firefox ESR”</de>
@@ -28,12 +28,12 @@ French_Default_Firefox_esr
    <fa>French localisation of Firefox ESR</fa>
    <fil_PH>French localisation of Firefox ESR</fil_PH>
    <fi>French localisation of Firefox ESR</fi>
-   <fr_BE>French localisation of Firefox ESR</fr_BE>
-   <fr>Localisation en français de Firefox ESR</fr>
+   <fr_BE>Localisation en français pour Firefox ESR</fr_BE>
+   <fr>Localisation en français pour Firefox ESR</fr>
    <gl_ES>French localisation of Firefox ESR</gl_ES>
    <gu>French localisation of Firefox ESR</gu>
    <he_IL>French localisation of Firefox ESR</he_IL>
-   <hi>French localisation of Firefox ESR</hi>
+   <hi>फायरफॉक्स ईएसआर का फ्रेंच संस्करण</hi>
    <hr>French localisation of Firefox ESR</hr>
    <hu>French localisation of Firefox ESR</hu>
    <id>French localisation of Firefox ESR</id>
@@ -55,8 +55,8 @@ French_Default_Firefox_esr
    <ro>French localisation of Firefox ESR</ro>
    <ru>French localisation of Firefox ESR</ru>
    <sk>French localisation of Firefox ESR</sk>
-   <sl>French localisation of Firefox ESR</sl>
-   <sq>French localisation of Firefox ESR</sq>
+   <sl>Francoske krajevne nastavitve za Firefox ESR</sl>
+   <sq>Përkthimi i Firefox-it ESR në frëngjisht</sq>
    <sr>French localisation of Firefox ESR</sr>
    <sv>Fransk lokalisering av Firefox ESR</sv>
    <th>French localisation of Firefox ESR</th>
