@@ -42,15 +42,13 @@ Frisian_Default_Firefox_esr
    <ja>西フリジアン語（オランダ）版 Firefox ESR</ja>
    <kk>Western Frisian (Netherlands) localisation of Firefox ESR</kk>
    <ko>Western Frisian (Netherlands) localisation of Firefox ESR</ko>
-   <ku>Western Frisian (Netherlands) localisation of Firefox ESR</ku>
    <lt>Western Frisian (Netherlands) localisation of Firefox ESR</lt>
    <mk>Western Frisian (Netherlands) localisation of Firefox ESR</mk>
    <mr>Western Frisian (Netherlands) localisation of Firefox ESR</mr>
    <nb_NO>Western Frisian (Netherlands) localisation of Firefox ESR</nb_NO>
    <nb>Vestfrisisk (nederlandsk) lokaltilpassing av Firefox ESR</nb>
    <nl_BE>Western Frisian (Netherlands) localisation of Firefox ESR</nl_BE>
-   <nl>West-Friese (Nederland) lokalisatie van Firefox ESR</nl>
-   <or>Western Frisian (Netherlands) localisation of Firefox ESR</or>
+   <nl>Western Frisian (Netherlands) localisation of Firefox ESR</nl>
    <pl>Western Frisian (Netherlands) localisation of Firefox ESR</pl>
    <pt_BR>Frísia Ocidental (Holanda) Localização para o Firefox ESR</pt_BR>
    <pt>Frísio Ocidental (Países Baixos) Localização para Firefox ESR</pt>
@@ -58,7 +56,6 @@ Frisian_Default_Firefox_esr
    <ru>Western Frisian (Netherlands) localisation of Firefox ESR</ru>
    <sk>Western Frisian (Netherlands) localisation of Firefox ESR</sk>
    <sl>Zahodno Frizijske (Nizozemska) krajevne nastavitve za Firefox ESR</sl>
-   <so>Western Frisian (Netherlands) localisation of Firefox ESR</so>
    <sq>Përkthimi i Firefox-it ESR në frizishte perëndimore (Holandë)</sq>
    <sr>Western Frisian (Netherlands) localisation of Firefox ESR</sr>
    <sv>Västfrisisk (Holland) lokalisering av Firefox ESR</sv>
