@@ -15,29 +15,30 @@ Galician_Default_Firefox_esr
    <be>Galician localisation of Firefox ESR</be>
    <bg>Galician localisation of Firefox ESR</bg>
    <bn>Galician localisation of Firefox ESR</bn>
-   <ca>Galician localisation of Firefox ESR</ca>
+   <ca>Localització de Firefox-ESR en Gallec</ca>
    <cs>Galician localisation of Firefox ESR</cs>
    <da>Galician localisation of Firefox ESR</da>
    <de>Galegische Lokalisation von “Firefox ESR”</de>
    <el>Γαλικία για Firefox ESR</el>
    <en>Galician localisation of Firefox ESR</en>
-   <es_ES>Galician localisation of Firefox ESR</es_ES>
+   <es_ES>Localización Gallego de Firefox ESR</es_ES>
    <es>Localización Gallego de Firefox ESR</es>
    <et>Galician localisation of Firefox ESR</et>
    <eu>Galician localisation of Firefox ESR</eu>
    <fa>Galician localisation of Firefox ESR</fa>
    <fil_PH>Galician localisation of Firefox ESR</fil_PH>
    <fi>Galician localisation of Firefox ESR</fi>
-   <fr_BE>Localisation en galicien de Firefox ESR</fr_BE>
-   <fr>Localisation en galicien de Firefox ESR</fr>
+   <fr_BE>Localisation en galicien pour Firefox ESR</fr_BE>
+   <fr>Localisation en galicien pour Firefox ESR</fr>
    <gl_ES>Galician localisation of Firefox ESR</gl_ES>
+   <gu>Galician localisation of Firefox ESR</gu>
    <he_IL>Galician localisation of Firefox ESR</he_IL>
-   <hi>Galician localisation of Firefox ESR</hi>
+   <hi>फायरफॉक्स ईएसआर का गलिसियाई संस्करण</hi>
    <hr>Galician localisation of Firefox ESR</hr>
    <hu>Galician localisation of Firefox ESR</hu>
    <id>Galician localisation of Firefox ESR</id>
    <is>Galician localisation of Firefox ESR</is>
-   <it>Galician localisation of Firefox ESR</it>
+   <it>Localizzazione in lingua galiziana di Firefox ESR</it>
    <ja>ガリシア語版 Firefox ESR</ja>
    <kk>Galician localisation of Firefox ESR</kk>
    <ko>Galician localisation of Firefox ESR</ko>
@@ -54,12 +55,12 @@ Galician_Default_Firefox_esr
    <ro>Galician localisation of Firefox ESR</ro>
    <ru>Galician localisation of Firefox ESR</ru>
    <sk>Galician localisation of Firefox ESR</sk>
-   <sl>Galician localisation of Firefox ESR</sl>
-   <sq>Galician localisation of Firefox ESR</sq>
+   <sl>Galicijske  krajevne nastavitve za Firefox ESR</sl>
+   <sq>Përkthimi i Firefox-it ESR në galicisht</sq>
    <sr>Galician localisation of Firefox ESR</sr>
    <sv>Galicisk lokalisering av Firefox ESR</sv>
    <th>Galician localisation of Firefox ESR</th>
-   <tr>Galician localisation of Firefox ESR</tr>
+   <tr>Firefox ESR Galiçyaca yerelleştirmesi</tr>
    <uk>Galician localisation of Firefox ESR</uk>
    <vi>Galician localisation of Firefox ESR</vi>
    <zh_CN>Galician localisation of Firefox ESR</zh_CN>
