@@ -15,29 +15,30 @@ Modern Greek
    <be>Greek dictionary for hunspell</be>
    <bg>Greek dictionary for hunspell</bg>
    <bn>Greek dictionary for hunspell</bn>
-   <ca>Greek dictionary for hunspell</ca>
+   <ca>Diccionari Grec per hunspell</ca>
    <cs>Greek dictionary for hunspell</cs>
    <da>Greek dictionary for hunspell</da>
-   <de>Greek dictionary for hunspell</de>
+   <de>Griechisches Wörterbuch für “Hunspell”</de>
    <el>Ελληνικό λεξικό για hunspell</el>
    <en>Greek dictionary for hunspell</en>
-   <es_ES>Greek dictionary for hunspell</es_ES>
+   <es_ES>Diccionario Griego para hunspell</es_ES>
    <es>Diccionario Griego para hunspell</es>
    <et>Greek dictionary for hunspell</et>
    <eu>Greek dictionary for hunspell</eu>
    <fa>Greek dictionary for hunspell</fa>
    <fil_PH>Greek dictionary for hunspell</fil_PH>
    <fi>Greek dictionary for hunspell</fi>
-   <fr_BE>Greek dictionary for hunspell</fr_BE>
-   <fr>Greek dictionary for hunspell</fr>
+   <fr_BE>Grec dictionnaire pour hunspell</fr_BE>
+   <fr>Grec dictionnaire pour hunspell</fr>
    <gl_ES>Greek dictionary for hunspell</gl_ES>
+   <gu>Greek dictionary for hunspell</gu>
    <he_IL>Greek dictionary for hunspell</he_IL>
-   <hi>Greek dictionary for hunspell</hi>
+   <hi>Hunspell हेतु यूनानी शब्दकोष</hi>
    <hr>Greek dictionary for hunspell</hr>
    <hu>Greek dictionary for hunspell</hu>
    <id>Greek dictionary for hunspell</id>
    <is>Greek dictionary for hunspell</is>
-   <it>Greek dictionary for hunspell</it>
+   <it>Dizionario greco per hunspell</it>
    <ja>Hunspell 用ギリシャ語辞書</ja>
    <kk>Greek dictionary for hunspell</kk>
    <ko>Greek dictionary for hunspell</ko>
@@ -45,21 +46,21 @@ Modern Greek
    <mk>Greek dictionary for hunspell</mk>
    <mr>Greek dictionary for hunspell</mr>
    <nb_NO>Greek dictionary for hunspell</nb_NO>
-   <nb>Greek dictionary for hunspell</nb>
+   <nb>Gresk ordliste for hunspell</nb>
    <nl_BE>Greek dictionary for hunspell</nl_BE>
    <nl>Greek dictionary for hunspell</nl>
    <pl>Greek dictionary for hunspell</pl>
-   <pt_BR>Greek dictionary for hunspell</pt_BR>
-   <pt>Greek dictionary for hunspell</pt>
+   <pt_BR>Dicionário Grego para o hunspell (corretor ortográfico e analisador morfológico)</pt_BR>
+   <pt>Dicionário Grego para hunspell</pt>
    <ro>Greek dictionary for hunspell</ro>
    <ru>Greek dictionary for hunspell</ru>
    <sk>Greek dictionary for hunspell</sk>
-   <sl>Greek dictionary for hunspell</sl>
-   <sq>Greek dictionary for hunspell</sq>
+   <sl>Grški slovar za hunspell</sl>
+   <sq>Meta-Paketë gjuhësore për LibreOffice-in në greqisht</sq>
    <sr>Greek dictionary for hunspell</sr>
-   <sv>Greek dictionary for hunspell</sv>
+   <sv>Grekisk ordbok för hunspell</sv>
    <th>Greek dictionary for hunspell</th>
-   <tr>Greek dictionary for hunspell</tr>
+   <tr>Hunspell için Yunanca sözlük</tr>
    <uk>Greek dictionary for hunspell</uk>
    <vi>Greek dictionary for hunspell</vi>
    <zh_CN>Greek dictionary for hunspell</zh_CN>
