@@ -31,8 +31,9 @@ Greek_LO_Latest_main
    <fr_BE>Méta-paquet langue grecque pour LibreOffice</fr_BE>
    <fr>Méta-paquet langue grecque pour LibreOffice</fr>
    <gl_ES>Grego Meta-paquete de Idioma para LibreOffice</gl_ES>
+   <gu>Greek Language Meta-Package for LibreOffice</gu>
    <he_IL>Greek Language Meta-Package for LibreOffice</he_IL>
-   <hi>Greek Language Meta-Package for LibreOffice</hi>
+   <hi>लिब्रे-ऑफिस हेतु यूनानी भाषा मेटा-पैकेज</hi>
    <hr>Greek Language Meta-Package for LibreOffice</hr>
    <hu>Greek Language Meta-Package for LibreOffice</hu>
    <id>Greek Language Meta-Package for LibreOffice</id>
@@ -55,7 +56,7 @@ Greek_LO_Latest_main
    <ru>Greek Language Meta-Package for LibreOffice</ru>
    <sk>Greek Language Meta-Package for LibreOffice</sk>
    <sl>Grški jezikovni meta-paket za LibreOffice</sl>
-   <sq>Greek Language Meta-Package for LibreOffice</sq>
+   <sq>Meta-Paketë gjuhësore për LibreOffice-in në greqisht</sq>
    <sr>Greek Language Meta-Package for LibreOffice</sr>
    <sv>Grekiskt Språk Meta-Paket för LibreOffice</sv>
    <th>Meta-Package ภาษา Greek สำหรับ LibreOffice</th>
