@@ -42,7 +42,6 @@ Hungarian_LO_Latest_full
    <ja>ハンガリー語 LibreOffice 言語メタパッケージ</ja>
    <kk>Hungarian LibreOffice Language Meta-Package</kk>
    <ko>Hungarian LibreOffice Language Meta-Package</ko>
-   <ku>Hungarian LibreOffice Language Meta-Package</ku>
    <lt>Hungarian LibreOffice Language Meta-Package</lt>
    <mk>Hungarian LibreOffice Language Meta-Package</mk>
    <mr>Hungarian LibreOffice Language Meta-Package</mr>
@@ -50,7 +49,6 @@ Hungarian_LO_Latest_full
    <nb>Ungarsk språkpakke for LibreOffice</nb>
    <nl_BE>Hungarian LibreOffice Language Meta-Package</nl_BE>
    <nl>Hongaarse LibreOffice Taal Meta-Pakket</nl>
-   <or>Hungarian LibreOffice Language Meta-Package</or>
    <pl>Węgierski metapakiet językowy dla LibreOffice</pl>
    <pt_BR>Húngaro Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Húngaro Meta-Pacote de Idioma para LibreOffice</pt>
@@ -58,7 +56,6 @@ Hungarian_LO_Latest_full
    <ru>Hungarian LibreOffice Language Meta-Package</ru>
    <sk>Hungarian LibreOffice Language Meta-Package</sk>
    <sl>Madžarski jezikovni metapaket za LibreOffice</sl>
-   <so>Hungarian LibreOffice Language Meta-Package</so>
    <sq>Përkthimi i Firefox-it në hungarisht</sq>
    <sr>Hungarian LibreOffice Language Meta-Package</sr>
    <sv>Ungerskt LibreOffice Språk Meta-Paket </sv>
