@@ -28,11 +28,12 @@ Italian_LO_main
    <fa>Italian LibreOffice Language Meta-Package</fa>
    <fil_PH>Italian LibreOffice Language Meta-Package</fil_PH>
    <fi>Italialainen kielipaketti LibreOffice:lle</fi>
-   <fr_BE>Italian LibreOffice Language Meta-Package</fr_BE>
+   <fr_BE>Méta-paquet langue italienne pour LibreOffice</fr_BE>
    <fr>Méta-paquet langue italienne pour LibreOffice</fr>
    <gl_ES>Italiano Meta-paquete de Idioma para LibreOffice</gl_ES>
+   <gu>Italian LibreOffice Language Meta-Package</gu>
    <he_IL>Italian LibreOffice Language Meta-Package</he_IL>
-   <hi>Italian LibreOffice Language Meta-Package</hi>
+   <hi>लिब्रे-ऑफिस हेतु इतालवी भाषा मेटा-पैकेज</hi>
    <hr>Italian LibreOffice Language Meta-Package</hr>
    <hu>Italian LibreOffice Language Meta-Package</hu>
    <id>Italian LibreOffice Language Meta-Package</id>
@@ -54,8 +55,8 @@ Italian_LO_main
    <ro>Italian LibreOffice Language Meta-Package</ro>
    <ru>Italian LibreOffice Language Meta-Package</ru>
    <sk>Italian LibreOffice Language Meta-Package</sk>
-   <sl>Italian LibreOffice Language Meta-Package</sl>
-   <sq>Italian LibreOffice Language Meta-Package</sq>
+   <sl>Itlaijanski jezikovni metapaket za LibreOffice</sl>
+   <sq>Meta-Paketë gjuhësore për LibreOffice-in në italisht</sq>
    <sr>Italian LibreOffice Language Meta-Package</sr>
    <sv>Italienskt LibreOffice Språk-Meta-Paket</sv>
    <th>Meta-Package ภาษา Italian สำหรับ LibreOffice</th>
