@@ -42,7 +42,6 @@ Kazakh_LO_Latest_full
    <ja>LibreOffice用のカンナダ語メタパッケージ</ja>
    <kk>Kannada Language Meta-Package for LibreOffice</kk>
    <ko>Kannada Language Meta-Package for LibreOffice</ko>
-   <ku>Kannada Language Meta-Package for LibreOffice</ku>
    <lt>Kannada Language Meta-Package for LibreOffice</lt>
    <mk>Kannada Language Meta-Package for LibreOffice</mk>
    <mr>Kannada Language Meta-Package for LibreOffice</mr>
@@ -50,7 +49,6 @@ Kazakh_LO_Latest_full
    <nb>Kannada språkpakke for LibreOffice</nb>
    <nl_BE>Kannada Language Meta-Package for LibreOffice</nl_BE>
    <nl>Kannada Taal Meta-Pakket voor LibreOffice</nl>
-   <or>Kannada Language Meta-Package for LibreOffice</or>
    <pl>Meta-pakiet języka kannada dla LibreOffice</pl>
    <pt_BR>Canarim Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Canarim Meta-Pacote de Idioma para LibreOffice</pt>
@@ -58,7 +56,6 @@ Kazakh_LO_Latest_full
    <ru>Kannada Language Meta-Package for LibreOffice</ru>
    <sk>Kannada Language Meta-Package for LibreOffice</sk>
    <sl>Kannadski jezikovni meta-paket za LibreOffice</sl>
-   <so>Kannada Language Meta-Package for LibreOffice</so>
    <sq>Meta-Paketë gjuhësore për LibreOffice-in në kanada</sq>
    <sr>Kannada Language Meta-Package for LibreOffice</sr>
    <sv>Kannada Språk Meta-Paket för LibreOffice</sv>
@@ -92,7 +89,6 @@ libreoffice-writer
 libreoffice-base
 libreoffice-gtk3
 libreoffice-l10n-kk
-libreoffice-java-common
 </install_package_names>
 
 <postinstall>
@@ -108,7 +104,6 @@ libreoffice-impress
 libreoffice-math
 libreoffice-writer
 libreoffice-base
-libreoffice-java-common
 libreoffice-gtk3
 libreoffice-l10n-kk
 </uninstall_package_names>
