@@ -28,12 +28,12 @@ Korean_Input
    <fa>Korean Fonts and ibus</fa>
    <fil_PH>Korean Fonts and ibus</fil_PH>
    <fi>Korean Fonts and ibus</fi>
-   <fr_BE>Korean Fonts and ibus</fr_BE>
+   <fr_BE>Polices coréennes et ibus</fr_BE>
    <fr>Polices coréennes et ibus</fr>
    <gl_ES>Korean Fonts and ibus</gl_ES>
    <gu>Korean Fonts and ibus</gu>
    <he_IL>Korean Fonts and ibus</he_IL>
-   <hi>Korean Fonts and ibus</hi>
+   <hi>कोरियाई मुद्रलिपि व Ibus</hi>
    <hr>Korean Fonts and ibus</hr>
    <hu>Korean Fonts and ibus</hu>
    <id>Korean Fonts and ibus</id>
@@ -50,13 +50,13 @@ Korean_Input
    <nl_BE>Korean Fonts and ibus</nl_BE>
    <nl>Koreaanse Fonts en ibus</nl>
    <pl>Koreańskie fonty i ibus</pl>
-   <pt_BR>Coreano Fontes e ibus</pt_BR>
+   <pt_BR>Pacotes de Fontes Coreano e ibus</pt_BR>
    <pt>Coreano Fontes e ibus</pt>
    <ro>Korean Fonts and ibus</ro>
    <ru>Korean Fonts and ibus</ru>
    <sk>Korean Fonts and ibus</sk>
    <sl>Korejske pisave in ibus</sl>
-   <sq>Korean Fonts and ibus</sq>
+   <sq>Shkronja dhe ibus për koreançen</sq>
    <sr>Korean Fonts and ibus</sr>
    <sv>Koreanska Typsnitt och ibus</sv>
    <th>Korean Fonts and ibus</th>
