@@ -28,12 +28,12 @@ Kurmanji_LO_main
    <fa>Kurmanji Language Meta-Package for LibreOffice</fa>
    <fil_PH>Kurmanji Language Meta-Package for LibreOffice</fil_PH>
    <fi>Kurmandzinkielinen kielipaketti LibreOffice:lle</fi>
-   <fr_BE>Kurmanji Language Meta-Package for LibreOffice</fr_BE>
+   <fr_BE>Méta-Paquet en langue kurmanji pour LibreOffice</fr_BE>
    <fr>Méta-Paquet en langue kurmanji pour LibreOffice</fr>
    <gl_ES>Curmanji Meta-paquete de Idioma para LibreOffice</gl_ES>
    <gu>Kurmanji Language Meta-Package for LibreOffice</gu>
    <he_IL>Kurmanji Language Meta-Package for LibreOffice</he_IL>
-   <hi>Kurmanji Language Meta-Package for LibreOffice</hi>
+   <hi>लिब्रे-ऑफिस हेतु कुरमानी भाषा मेटा-पैकेज</hi>
    <hr>Kurmanji Language Meta-Package for LibreOffice</hr>
    <hu>Kurmanji Language Meta-Package for LibreOffice</hu>
    <id>Kurmanji Language Meta-Package for LibreOffice</id>
@@ -56,7 +56,7 @@ Kurmanji_LO_main
    <ru>Kurmanji Language Meta-Package for LibreOffice</ru>
    <sk>Kurmanji Language Meta-Package for LibreOffice</sk>
    <sl>Kurmanjski jezikovni meta-paket za LibreOffice</sl>
-   <sq>Kurmanji Language Meta-Package for LibreOffice</sq>
+   <sq>Meta-Paketë gjuhësore për LibreOffice-in në kurmanxhi</sq>
    <sr>Kurmanji Language Meta-Package for LibreOffice</sr>
    <sv>Kurmanji Språk Meta-Paket för LibreOffice</sv>
    <th>Meta-Package ภาษา Kurmanji สำหรับ LibreOffice</th>
