@@ -42,7 +42,6 @@ Lithuanian_Default_Firefox_esr
    <ja>リトアニア語版 Firefox ESR</ja>
    <kk>Lithuanian localisation of Firefox ESR</kk>
    <ko>Lithuanian localisation of Firefox ESR</ko>
-   <ku>Lithuanian localisation of Firefox ESR</ku>
    <lt>Lithuanian localisation of Firefox ESR</lt>
    <mk>Lithuanian localisation of Firefox ESR</mk>
    <mr>Lithuanian localisation of Firefox ESR</mr>
@@ -50,7 +49,6 @@ Lithuanian_Default_Firefox_esr
    <nb>Litauisk lokaltilpassing av Firefox ESR</nb>
    <nl_BE>Lithuanian localisation of Firefox ESR</nl_BE>
    <nl>Lithuanian localisation of Firefox ESR</nl>
-   <or>Lithuanian localisation of Firefox ESR</or>
    <pl>Lithuanian localisation of Firefox ESR</pl>
    <pt_BR>Lituano Localização para o Firefox ESR</pt_BR>
    <pt>Lituano Localização para Firefox ESR</pt>
@@ -58,7 +56,6 @@ Lithuanian_Default_Firefox_esr
    <ru>Lithuanian localisation of Firefox ESR</ru>
    <sk>Lithuanian localisation of Firefox ESR</sk>
    <sl>Litvanske krajevne nastavitve za Firefox ESR</sl>
-   <so>Lithuanian localisation of Firefox ESR</so>
    <sq>Përkthimi i Firefox-it ESR në lituanisht</sq>
    <sr>Lithuanian localisation of Firefox ESR</sr>
    <sv>Litauisk lokalisering av Firefox ESR</sv>
