@@ -28,12 +28,12 @@ Lithuanian_LO_main
    <fa>Lithuanian Language Meta-Package for LibreOffice</fa>
    <fil_PH>Lithuanian Language Meta-Package for LibreOffice</fil_PH>
    <fi>Liettualainen kielipaketti LibreOffice:lle</fi>
-   <fr_BE>Lithuanian Language Meta-Package for LibreOffice</fr_BE>
+   <fr_BE>Méta-Paquet en langue lituanienne pour LibreOffice</fr_BE>
    <fr>Méta-Paquet en langue lituanienne pour LibreOffice</fr>
    <gl_ES>Lituano Meta-paquete de Idioma para LibreOffice</gl_ES>
    <gu>Lithuanian Language Meta-Package for LibreOffice</gu>
    <he_IL>Lithuanian Language Meta-Package for LibreOffice</he_IL>
-   <hi>Lithuanian Language Meta-Package for LibreOffice</hi>
+   <hi>लिब्रे-ऑफिस हेतु लिथुआनियाई भाषा मेटा-पैकेज</hi>
    <hr>Lithuanian Language Meta-Package for LibreOffice</hr>
    <hu>Lithuanian Language Meta-Package for LibreOffice</hu>
    <id>Lithuanian Language Meta-Package for LibreOffice</id>
@@ -55,8 +55,8 @@ Lithuanian_LO_main
    <ro>Lithuanian Language Meta-Package for LibreOffice</ro>
    <ru>Lithuanian Language Meta-Package for LibreOffice</ru>
    <sk>Lithuanian Language Meta-Package for LibreOffice</sk>
-   <sl>Latvijski jezikovni meta-paket za LibreOffice</sl>
-   <sq>Lithuanian Language Meta-Package for LibreOffice</sq>
+   <sl>Litvanski jezikovni meta-paket za LibreOffice</sl>
+   <sq>Meta-Paketë gjuhësore për LibreOffice-in në lituanisht</sq>
    <sr>Lithuanian Language Meta-Package for LibreOffice</sr>
    <sv>Litauiskt Språk Meta-Paket för LibreOffice</sv>
    <th>Meta-Package ภาษา Lithuanian สำหรับ LibreOffice</th>
