@@ -28,11 +28,12 @@ Marathi_LO_full
    <fa>Marathi Language Meta-Package for LibreOffice</fa>
    <fil_PH>Marathi Language Meta-Package for LibreOffice</fil_PH>
    <fi>Marathinkielinen kielipaketti LibreOffice:lle</fi>
-   <fr_BE>Marathi Language Meta-Package for LibreOffice</fr_BE>
+   <fr_BE>Méta-Paquet en langue marathi pour LibreOffice</fr_BE>
    <fr>Méta-Paquet en langue marathi pour LibreOffice</fr>
    <gl_ES>Marata Meta-paquete de Idioma para LibreOffice</gl_ES>
+   <gu>Marathi Language Meta-Package for LibreOffice</gu>
    <he_IL>Marathi Language Meta-Package for LibreOffice</he_IL>
-   <hi>Marathi Language Meta-Package for LibreOffice</hi>
+   <hi>लिब्रे-ऑफिस हेतु मराठी भाषा मेटा-पैकेज</hi>
    <hr>Marathi Language Meta-Package for LibreOffice</hr>
    <hu>Marathi Language Meta-Package for LibreOffice</hu>
    <id>Marathi Language Meta-Package for LibreOffice</id>
@@ -55,7 +56,7 @@ Marathi_LO_full
    <ru>Marathi Language Meta-Package for LibreOffice</ru>
    <sk>Marathi Language Meta-Package for LibreOffice</sk>
    <sl>Maratski jezikovni meta-paket za LibreOffice</sl>
-   <sq>Marathi Language Meta-Package for LibreOffice</sq>
+   <sq>Meta-Paketë gjuhësore për LibreOffice-in në marati</sq>
    <sr>Marathi Language Meta-Package for LibreOffice</sr>
    <sv>Marathi Språk Meta-Paket för LibreOffice</sv>
    <th>Meta-Package ภาษา Marathi สำหรับ LibreOffice</th>
