@@ -31,8 +31,9 @@ Mongolian_LO_main
    <fr_BE>Méta-Paquet en langue mongole pour LibreOffice</fr_BE>
    <fr>Méta-Paquet en langue mongole pour LibreOffice</fr>
    <gl_ES>Mongol Meta-paquete de Idioma para LibreOffice</gl_ES>
+   <gu>Mongolian Language Meta-Package for LibreOffice</gu>
    <he_IL>Mongolian Language Meta-Package for LibreOffice</he_IL>
-   <hi>Mongolian Language Meta-Package for LibreOffice</hi>
+   <hi>लिब्रे-ऑफिस हेतु मंगोल भाषा मेटा-पैकेज</hi>
    <hr>Mongolian Language Meta-Package for LibreOffice</hr>
    <hu>Mongolian Language Meta-Package for LibreOffice</hu>
    <id>Mongolian Language Meta-Package for LibreOffice</id>
@@ -55,7 +56,7 @@ Mongolian_LO_main
    <ru>Mongolian Language Meta-Package for LibreOffice</ru>
    <sk>Mongolian Language Meta-Package for LibreOffice</sk>
    <sl>Mongolski jezikovni meta-paket za LibreOffice</sl>
-   <sq>Mongolian Language Meta-Package for LibreOffice</sq>
+   <sq>Meta-Paketë gjuhësore për LibreOffice-in në mongolisht</sq>
    <sr>Mongolian Language Meta-Package for LibreOffice</sr>
    <sv>Mongoliskt Språk Meta-Paket för LibreOffice</sv>
    <th>Meta-Package ภาษา Mongolian สำหรับ LibreOffice</th>
