@@ -29,12 +29,12 @@ OBS-Studio
    <fa>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</fa>
    <fil_PH>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</fil_PH>
    <fi>OBS-Studio - striimaa videota ja toteuta ohjelmalähetyksiä (vaatii OpenGL 3 laitteiston)</fi>
-   <fr_BE>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</fr_BE>
+   <fr_BE>OBS-Studio - Diffusion vidéo et capture vidéo d'écran (support OpenGL 3 nécessaire)</fr_BE>
    <fr>OBS-Studio - Diffusion vidéo et capture vidéo d'écran (support OpenGL 3 nécessaire)</fr>
    <gl_ES>OBS-Studio - Visualización de vídeos de internet e creación de vídeos da pantalla (require equipamento OpenGL 3)</gl_ES>
    <gu>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</gu>
    <he_IL>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</he_IL>
-   <hi>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</hi>
+   <hi>ओबीएस स्टूडियो - वीडियो व स्क्रीन सहभाजन स्ट्रीम साधन (ओपेन जीएल 3 हार्डवेयर आवश्यक)</hi>
    <hr>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</hr>
    <hu>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</hu>
    <id>OBS-Studio - Streaming Video and Screencaster (OpenGL 3 hardware required)</id>
