@@ -28,12 +28,12 @@ Occitan_LO_main
    <fa>Occitan Language Meta-Package for LibreOffice</fa>
    <fil_PH>Occitan Language Meta-Package for LibreOffice</fil_PH>
    <fi>Oksitaaninen kielipaketti LibreOffice:lle</fi>
-   <fr_BE>Occitan Language Meta-Package for LibreOffice</fr_BE>
+   <fr_BE>Méta-paquet langue occitane pour LibreOffice</fr_BE>
    <fr>Méta-paquet langue occitane pour LibreOffice</fr>
    <gl_ES>Occitano Meta-paquete de Idioma para LibreOffice</gl_ES>
    <gu>Occitan Language Meta-Package for LibreOffice</gu>
    <he_IL>Occitan Language Meta-Package for LibreOffice</he_IL>
-   <hi>Occitan Language Meta-Package for LibreOffice</hi>
+   <hi>लिब्रे-ऑफिस हेतु ओसीटान भाषा मेटा-पैकेज</hi>
    <hr>Occitan Language Meta-Package for LibreOffice</hr>
    <hu>Occitan Language Meta-Package for LibreOffice</hu>
    <id>Occitan Language Meta-Package for LibreOffice</id>
@@ -56,7 +56,7 @@ Occitan_LO_main
    <ru>Occitan Language Meta-Package for LibreOffice</ru>
    <sk>Occitan Language Meta-Package for LibreOffice</sk>
    <sl>Okitanski jezikovni meta-paket za LibreOffice</sl>
-   <sq>Occitan Language Meta-Package for LibreOffice</sq>
+   <sq>Meta-Paketë gjuhësore për LibreOffice-in në oçitanisht</sq>
    <sr>Occitan Language Meta-Package for LibreOffice</sr>
    <sv>Occitan Språk Meta-Paket för LibreOffice</sv>
    <th>Meta-Package ภาษา Occitan สำหรับ LibreOffice</th>
