@@ -15,13 +15,13 @@ Oriya_LO_main
    <be>Oriya Language Meta-Package for LibreOffice</be>
    <bg>Oriya Language Meta-Package for LibreOffice</bg>
    <bn>Oriya Language Meta-Package for LibreOffice</bn>
-   <ca>Oriya Language Meta-Package for LibreOffice</ca>
+   <ca>Metapaquet d'idioma Oriya per LibreOffice</ca>
    <cs>Oriya Language Meta-Package for LibreOffice</cs>
    <da>Oriya Language Meta-Package for LibreOffice</da>
    <de>Indisches Metapaket von “LibreOffice” für die Sprache “Odia”</de>
    <el>LibreOffice στα Oriya</el>
    <en>Oriya Language Meta-Package for LibreOffice</en>
-   <es_ES>Oriya Language Meta-Package for LibreOffice</es_ES>
+   <es_ES>Meta-Paquete de idioma Oriya para LibreOffice</es_ES>
    <es>Metapaquete de idioma Oriya para LibreOffice</es>
    <et>Oriya Language Meta-Package for LibreOffice</et>
    <eu>Oriya Language Meta-Package for LibreOffice</eu>
@@ -31,13 +31,14 @@ Oriya_LO_main
    <fr_BE>Méta-Paquet de langue oriya (Inde) pour LibreOffice</fr_BE>
    <fr>Méta-Paquet de langue oriya (Inde) pour LibreOffice</fr>
    <gl_ES>Oriya Language Meta-Package for LibreOffice</gl_ES>
+   <gu>Oriya Language Meta-Package for LibreOffice</gu>
    <he_IL>Oriya Language Meta-Package for LibreOffice</he_IL>
-   <hi>Oriya Language Meta-Package for LibreOffice</hi>
+   <hi>लिब्रे-ऑफिस हेतु ओड़िया भाषा मेटा-पैकेज</hi>
    <hr>Oriya Language Meta-Package for LibreOffice</hr>
    <hu>Oriya Language Meta-Package for LibreOffice</hu>
    <id>Oriya Language Meta-Package for LibreOffice</id>
    <is>Oriya Language Meta-Package for LibreOffice</is>
-   <it>Oriya Language Meta-Package for LibreOffice</it>
+   <it>Meta-pacchetto linguaggio oriya per LibreOffice</it>
    <ja>LibreOffice用オリヤー語メタパッケージ</ja>
    <kk>Oriya Language Meta-Package for LibreOffice</kk>
    <ko>Oriya Language Meta-Package for LibreOffice</ko>
@@ -50,16 +51,16 @@ Oriya_LO_main
    <nl>Oriya Language Meta-Package for LibreOffice</nl>
    <pl>Oriya Language Meta-Package for LibreOffice</pl>
    <pt_BR>Oriá Pacote de Idioma para o LibreOffice</pt_BR>
-   <pt>Oriya Language Meta-Package for LibreOffice</pt>
+   <pt>Oriá Meta-Pacote de Idioma para LibreOffice</pt>
    <ro>Oriya Language Meta-Package for LibreOffice</ro>
    <ru>Oriya Language Meta-Package for LibreOffice</ru>
    <sk>Oriya Language Meta-Package for LibreOffice</sk>
-   <sl>Oriya Language Meta-Package for LibreOffice</sl>
-   <sq>Oriya Language Meta-Package for LibreOffice</sq>
+   <sl>Orijski jezikovni meta-paket za LibreOffice</sl>
+   <sq>Meta-Paketë gjuhësore për LibreOffice-in në orijase</sq>
    <sr>Oriya Language Meta-Package for LibreOffice</sr>
    <sv>Oriya Språk Meta-Paket för LibreOffice</sv>
    <th>Oriya Language Meta-Package for LibreOffice</th>
-   <tr>Oriya Language Meta-Package for LibreOffice</tr>
+   <tr>LibreOffice için Odia Dili Üst-Paketi</tr>
    <uk>Oriya Language Meta-Package for LibreOffice</uk>
    <vi>Oriya Language Meta-Package for LibreOffice</vi>
    <zh_CN>Oriya Language Meta-Package for LibreOffice</zh_CN>
