@@ -42,7 +42,6 @@ Polish_LO_Latest_full
    <ja>LibreOffice用ポーランド語メタパッケージ</ja>
    <kk>Polish Language Meta-Package for LibreOffice</kk>
    <ko>Polish Language Meta-Package for LibreOffice</ko>
-   <ku>Polish Language Meta-Package for LibreOffice</ku>
    <lt>Polish Language Meta-Package for LibreOffice</lt>
    <mk>Polish Language Meta-Package for LibreOffice</mk>
    <mr>Polish Language Meta-Package for LibreOffice</mr>
@@ -50,7 +49,6 @@ Polish_LO_Latest_full
    <nb>Polsk språkpakke for LibreOffice</nb>
    <nl_BE>Polish Language Meta-Package for LibreOffice</nl_BE>
    <nl>Poolse Taal Meta-Pakket voor LibreOffice</nl>
-   <or>Polish Language Meta-Package for LibreOffice</or>
    <pl>Polski metapakiet językowy dla LibreOffice</pl>
    <pt_BR>Polonês Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Polaco Meta-Pacote de Idioma para LibreOffice</pt>
@@ -58,7 +56,6 @@ Polish_LO_Latest_full
    <ru>Polish Language Meta-Package for LibreOffice</ru>
    <sk>Polish Language Meta-Package for LibreOffice</sk>
    <sl>Poljski jezikovni meta-paket za LibreOffice</sl>
-   <so>Polish Language Meta-Package for LibreOffice</so>
    <sq>Meta-Paketë gjuhësore për LibreOffice-in në polonisht</sq>
    <sr>Polish Language Meta-Package for LibreOffice</sr>
    <sv>Polskt Språk Meta-Paket för LibreOffice </sv>
