@@ -31,8 +31,9 @@ Romanian_LO_Latest_full
    <fr_BE>Méta-paquet langue roumaine pour LibreOffice</fr_BE>
    <fr>Méta-paquet langue roumaine pour LibreOffice</fr>
    <gl_ES>Romanés Meta-paquete de Idioma para LibreOffice</gl_ES>
+   <gu>Romanian Language Meta-Package for LibreOffice</gu>
    <he_IL>Romanian Language Meta-Package for LibreOffice</he_IL>
-   <hi>Romanian Language Meta-Package for LibreOffice</hi>
+   <hi>लिब्रे-ऑफिस हेतु रोमानियाई भाषा मेटा-पैकेज</hi>
    <hr>Romanian Language Meta-Package for LibreOffice</hr>
    <hu>Romanian Language Meta-Package for LibreOffice</hu>
    <id>Romanian Language Meta-Package for LibreOffice</id>
@@ -54,8 +55,8 @@ Romanian_LO_Latest_full
    <ro>Romanian Language Meta-Package for LibreOffice</ro>
    <ru>Romanian Language Meta-Package for LibreOffice</ru>
    <sk>Romanian Language Meta-Package for LibreOffice</sk>
-   <sl>Romanian Language Meta-Package for LibreOffice</sl>
-   <sq>Romanian Language Meta-Package for LibreOffice</sq>
+   <sl>Romunski jezikovni meta-paket za LibreOffice</sl>
+   <sq>Meta-Paketë gjuhësore për LibreOffice-in në rumanisht</sq>
    <sr>Romanian Language Meta-Package for LibreOffice</sr>
    <sv>Rumänskt Språk Meta-Paket för LibreOffice </sv>
    <th>Meta-Package ภาษา Romanian สำหรับ LibreOffice</th>
