@@ -28,11 +28,12 @@ Scottish_LO_main
    <fa>Scottish_gaelic Language Meta-Package for LibreOffice</fa>
    <fil_PH>Scottish_gaelic Language Meta-Package for LibreOffice</fil_PH>
    <fi>Skotlantilais-gaelilainen kielipaketti LibreOffice:lle</fi>
-   <fr_BE>Scottish_gaelic Language Meta-Package for LibreOffice</fr_BE>
+   <fr_BE>Méta-Paquet en langue gaélique (Ecosse) pour LibreOffice</fr_BE>
    <fr>Méta-Paquet en langue gaélique (Ecosse) pour LibreOffice</fr>
    <gl_ES>Gaélico-escocés Meta-paquete de Idioma para LibreOffice</gl_ES>
+   <gu>Scottish_gaelic Language Meta-Package for LibreOffice</gu>
    <he_IL>Scottish_gaelic Language Meta-Package for LibreOffice</he_IL>
-   <hi>Scottish_gaelic Language Meta-Package for LibreOffice</hi>
+   <hi>लिब्रे-ऑफिस हेतु स्कॉटिश_गेलिक भाषा मेटा-पैकेज</hi>
    <hr>Scottish_gaelic Language Meta-Package for LibreOffice</hr>
    <hu>Scottish_gaelic Language Meta-Package for LibreOffice</hu>
    <id>Scottish_gaelic Language Meta-Package for LibreOffice</id>
@@ -49,13 +50,13 @@ Scottish_LO_main
    <nl_BE>Scottish_gaelic Language Meta-Package for LibreOffice</nl_BE>
    <nl>Schots-Gaelic Taal Meta-Pakket voor LibreOffice</nl>
    <pl>Meta-pakiet języka gaelickiego szkockiego dla LibreOffice</pl>
-   <pt_BR>Gaélica Escocesa Pacote de Idioma para o LibreOffice</pt_BR>
+   <pt_BR>Gaélico Escocês Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Gaélico_escocês Meta-Pacote de Idioma para LibreOffice</pt>
    <ro>Scottish_gaelic Language Meta-Package for LibreOffice</ro>
    <ru>Scottish_gaelic Language Meta-Package for LibreOffice</ru>
    <sk>Scottish_gaelic Language Meta-Package for LibreOffice</sk>
-   <sl>Škotski gelik jezikovni meta-paket za LibreOffice</sl>
-   <sq>Scottish_gaelic Language Meta-Package for LibreOffice</sq>
+   <sl>Škotsko gelške jezikovni meta-paket za LibreOffice</sl>
+   <sq>Meta-Paketë gjuhësore për LibreOffice-in në gaelike skoceze</sq>
    <sr>Scottish_gaelic Language Meta-Package for LibreOffice</sr>
    <sv>Skottsk_gaelic Språk Meta-Paket för LibreOffice</sv>
    <th>Meta-Package ภาษา Scottish_gaelic สำหรับ LibreOffice</th>
