@@ -42,7 +42,6 @@ Slovenian_LO_full
    <ja>LibreOffice用のスロベニア語メタパッケージ</ja>
    <kk>Slovenian Language Meta-Package for LibreOffice</kk>
    <ko>Slovenian Language Meta-Package for LibreOffice</ko>
-   <ku>Slovenian Language Meta-Package for LibreOffice</ku>
    <lt>Slovenian Language Meta-Package for LibreOffice</lt>
    <mk>Slovenian Language Meta-Package for LibreOffice</mk>
    <mr>Slovenian Language Meta-Package for LibreOffice</mr>
@@ -50,7 +49,6 @@ Slovenian_LO_full
    <nb>Slovensk språkpakke for LibreOffice</nb>
    <nl_BE>Slovenian Language Meta-Package for LibreOffice</nl_BE>
    <nl>Sloveens Taal Meta-Pakket voor LibreOffice</nl>
-   <or>Slovenian Language Meta-Package for LibreOffice</or>
    <pl>Słoweński meta-pakiet językowy dla LibreOffice</pl>
    <pt_BR>Esloveno Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Esloveno Meta-Pacote de Idioma para LibreOffice</pt>
@@ -58,7 +56,6 @@ Slovenian_LO_full
    <ru>Slovenian Language Meta-Package for LibreOffice</ru>
    <sk>Slovenian Language Meta-Package for LibreOffice</sk>
    <sl>Slovenski jezikovni meta-paket za LibreOffice</sl>
-   <so>Slovenian Language Meta-Package for LibreOffice</so>
    <sq>Meta-Paketë gjuhësore për LibreOffice-in në sllovenisht</sq>
    <sr>Slovenian Language Meta-Package for LibreOffice</sr>
    <sv>Sloveniskt Språk Meta-Paket för LibreOffice</sv>
@@ -78,12 +75,12 @@ all
 <screenshot>none</screenshot>
 
 <preinstall>
-echo "deb http://deb.debian.org/debian bullseye-backports main contrib non-free">/etc/apt/sources.list.d/pitemp.list
+echo "deb http://deb.debian.org/debian buster-backports main contrib non-free">/etc/apt/sources.list.d/pitemp.list
 apt-get update
 </preinstall>
 
 <install_package_names>
--t bullseye-backports libreoffice-base-core
+-t buster-backports libreoffice-base-core
 libreoffice-calc
 libreoffice-draw
 libreoffice-impress
@@ -92,7 +89,6 @@ libreoffice-writer
 libreoffice-base
 libreoffice-gtk3
 libreoffice-l10n-sl
-libreoffice-java-common
 </install_package_names>
 
 <postinstall>
@@ -108,7 +104,6 @@ libreoffice-impress
 libreoffice-math
 libreoffice-writer
 libreoffice-base
-libreoffice-java-common
 libreoffice-gtk3
 libreoffice-l10n-sl
 </uninstall_package_names>
