@@ -28,7 +28,7 @@ Slovenian_Firefox
    <fa>Slovenian localisation of Firefox</fa>
    <fil_PH>Slovenian localisation of Firefox</fil_PH>
    <fi>Slovenialainen Firefox-kotoistus</fi>
-   <fr_BE>Slovenian localisation of Firefox</fr_BE>
+   <fr_BE>Localisation en slovène pour Firefox</fr_BE>
    <fr>Localisation en slovène pour Firefox</fr>
    <gl_ES>Localización de Firefox ao esloveno</gl_ES>
    <gu>Slovenian localisation of Firefox</gu>
@@ -55,8 +55,8 @@ Slovenian_Firefox
    <ro>Slovenian localisation of Firefox</ro>
    <ru>Словенская локализация Firefox</ru>
    <sk>Slovenian localisation of Firefox</sk>
-   <sl>Slovenska lokalizacija za Firefox</sl>
-   <sq>Slovenian localisation of Firefox</sq>
+   <sl>Slovenske krajevne nastavitve za Firefox</sl>
+   <sq>Përkthimi i Firefox-it në sllovenisht</sq>
    <sr>Slovenian localisation of Firefox</sr>
    <sv>Slovensk lokalisering av Firefox</sv>
    <th>Slovenian localisation ของ Firefox</th>
