@@ -15,7 +15,7 @@ Swedish
    <be>Swedish dictionary for hunspell</be>
    <bg>Swedish dictionary for hunspell</bg>
    <bn>Swedish dictionary for hunspell</bn>
-   <ca>Swedish dictionary for hunspell</ca>
+   <ca>Diccionari Suec per hunspell</ca>
    <cs>Swedish dictionary for hunspell</cs>
    <da>Swedish dictionary for hunspell</da>
    <de>Schwedisches Wörterbuch für “Hunspell”</de>
@@ -28,12 +28,12 @@ Swedish
    <fa>Swedish dictionary for hunspell</fa>
    <fil_PH>Swedish dictionary for hunspell</fil_PH>
    <fi>Swedish dictionary for hunspell</fi>
-   <fr_BE>Swedish dictionary for hunspell</fr_BE>
+   <fr_BE>Suédois dictionnaire pour hunspell</fr_BE>
    <fr>Suédois dictionnaire pour hunspell</fr>
    <gl_ES>Swedish dictionary for hunspell</gl_ES>
    <gu>Swedish dictionary for hunspell</gu>
    <he_IL>Swedish dictionary for hunspell</he_IL>
-   <hi>Swedish dictionary for hunspell</hi>
+   <hi>Hunspell हेतु स्वीडिश शब्दकोष</hi>
    <hr>Swedish dictionary for hunspell</hr>
    <hu>Swedish dictionary for hunspell</hu>
    <id>Swedish dictionary for hunspell</id>
@@ -55,12 +55,12 @@ Swedish
    <ro>Swedish dictionary for hunspell</ro>
    <ru>Swedish dictionary for hunspell</ru>
    <sk>Swedish dictionary for hunspell</sk>
-   <sl>Swedish dictionary for hunspell</sl>
-   <sq>Swedish dictionary for hunspell</sq>
+   <sl>Švedski slovar za hunspell</sl>
+   <sq>Fjalor suedisht për hunspell</sq>
    <sr>Swedish dictionary for hunspell</sr>
    <sv>Svensk ordbok för hunspell</sv>
    <th>Swedish dictionary for hunspell</th>
-   <tr>Swedish dictionary for hunspell</tr>
+   <tr>Hunspell için İsveççe sözlük</tr>
    <uk>Swedish dictionary for hunspell</uk>
    <vi>Swedish dictionary for hunspell</vi>
    <zh_CN>Swedish dictionary for hunspell</zh_CN>
