@@ -31,8 +31,9 @@ Uighur_LO_full
    <fr_BE>Méta-Paquet en langue ouïgoure pour LibreOffice</fr_BE>
    <fr>Méta-Paquet en langue ouïgoure pour LibreOffice</fr>
    <gl_ES>Uigur Meta-paquete de Idioma para LibreOffice</gl_ES>
+   <gu>Uighur Language Meta-Package for LibreOffice</gu>
    <he_IL>Uighur Language Meta-Package for LibreOffice</he_IL>
-   <hi>Uighur Language Meta-Package for LibreOffice</hi>
+   <hi>लिब्रे-ऑफिस हेतु उइगुर भाषा मेटा-पैकेज</hi>
    <hr>Uighur Language Meta-Package for LibreOffice</hr>
    <hu>Uighur Language Meta-Package for LibreOffice</hu>
    <id>Uighur Language Meta-Package for LibreOffice</id>
@@ -55,7 +56,7 @@ Uighur_LO_full
    <ru>Uighur Language Meta-Package for LibreOffice</ru>
    <sk>Uighur Language Meta-Package for LibreOffice</sk>
    <sl>Ujgurski jezikovni meta-paket za LibreOffice</sl>
-   <sq>Uighur Language Meta-Package for LibreOffice</sq>
+   <sq>Meta-Paketë gjuhësore për LibreOffice-in në ujgure</sq>
    <sr>Uighur Language Meta-Package for LibreOffice</sr>
    <sv>Uighur Språk Meta-Paket för LibreOffice</sv>
    <th>Meta-Package ภาษา Uighur สำหรับ LibreOffice</th>
