@@ -15,7 +15,7 @@ Ukrainian
    <be>Ukrainian dictionary for hunspell</be>
    <bg>Ukrainian dictionary for hunspell</bg>
    <bn>Ukrainian dictionary for hunspell</bn>
-   <ca>Ukrainian dictionary for hunspell</ca>
+   <ca>Diccionari Ucraïnès per hunspell</ca>
    <cs>Ukrainian dictionary for hunspell</cs>
    <da>Ukrainian dictionary for hunspell</da>
    <de>Ukrainisches Wörterbuch für “Hunspell”</de>
@@ -28,12 +28,12 @@ Ukrainian
    <fa>Ukrainian dictionary for hunspell</fa>
    <fil_PH>Ukrainian dictionary for hunspell</fil_PH>
    <fi>Ukrainian dictionary for hunspell</fi>
-   <fr_BE>Ukrainian dictionary for hunspell</fr_BE>
+   <fr_BE>Ukrainien dictionnaire pour hunspell</fr_BE>
    <fr>Ukrainien dictionnaire pour hunspell</fr>
    <gl_ES>Ukrainian dictionary for hunspell</gl_ES>
    <gu>Ukrainian dictionary for hunspell</gu>
    <he_IL>Ukrainian dictionary for hunspell</he_IL>
-   <hi>Ukrainian dictionary for hunspell</hi>
+   <hi>Hunspell हेतु यूक्रेनी शब्दकोष</hi>
    <hr>Ukrainian dictionary for hunspell</hr>
    <hu>Ukrainian dictionary for hunspell</hu>
    <id>Ukrainian dictionary for hunspell</id>
@@ -55,12 +55,12 @@ Ukrainian
    <ro>Ukrainian dictionary for hunspell</ro>
    <ru>Ukrainian dictionary for hunspell</ru>
    <sk>Ukrainian dictionary for hunspell</sk>
-   <sl>Ukrainian dictionary for hunspell</sl>
-   <sq>Ukrainian dictionary for hunspell</sq>
+   <sl>Ukrajinski slovar za hunspell</sl>
+   <sq>Fjalor ukrainisht për hunspell</sq>
    <sr>Ukrainian dictionary for hunspell</sr>
    <sv>Ukrainsk ordbok för hunspell</sv>
    <th>Ukrainian dictionary for hunspell</th>
-   <tr>Ukrainian dictionary for hunspell</tr>
+   <tr>Hunspell için Ukraynaca sözlük</tr>
    <uk>Ukrainian dictionary for hunspell</uk>
    <vi>Ukrainian dictionary for hunspell</vi>
    <zh_CN>Ukrainian dictionary for hunspell</zh_CN>
