@@ -31,8 +31,9 @@ Ukrainian_LO_Latest_full
    <fr_BE>Localisation en ukrainien pour LibreOffice</fr_BE>
    <fr>Localisation en ukrainien pour LibreOffice</fr>
    <gl_ES>Localización do LibreOffice ao ucraniano</gl_ES>
+   <gu>Ukrainian localisation of LibreOffice</gu>
    <he_IL>תרגומי LibreOffice לאוקראינית</he_IL>
-   <hi>Ukrainian localisation of LibreOffice</hi>
+   <hi>लिब्रे-ऑफिस का यूक्रेनी संस्करण</hi>
    <hr>Ukrainian localisation of LibreOffice</hr>
    <hu>Ukrainian localisation of LibreOffice</hu>
    <id>Ukrainian localisation of LibreOffice</id>
@@ -54,8 +55,8 @@ Ukrainian_LO_Latest_full
    <ro>Ukrainian localisation of LibreOffice</ro>
    <ru>Ukrainian localisation of LibreOffice</ru>
    <sk>Ukrainian localisation of LibreOffice</sk>
-   <sl>Ukrainian localisation of LibreOffice</sl>
-   <sq>Ukrainian localisation of LibreOffice</sq>
+   <sl>Ukrajinske krajevne nastavitve za LibreOffice</sl>
+   <sq>Përkthim i LibreOffice-it në ukrainisht</sq>
    <sr>Ukrainian localisation of LibreOffice</sr>
    <sv>Ukrainsk lokalisering av LibreOffice</sv>
    <th>Ukrainian localisation ของ LibreOffice</th>
