@@ -31,8 +31,9 @@ Ukrainian_Firefox
    <fr_BE>Localisation en ukrainien pour Firefox</fr_BE>
    <fr>Localisation en ukrainien pour Firefox</fr>
    <gl_ES>Localización de Firefox ao ucranian</gl_ES>
+   <gu>Ukrainian localisation of Firefox</gu>
    <he_IL>תרגומי Firefox לאוקראינית</he_IL>
-   <hi>Ukrainian localisation of Firefox</hi>
+   <hi>फायरफॉक्स का यूक्रेनी संस्करण</hi>
    <hr>Ukrainian localisation of Firefox</hr>
    <hu>Ukrainian localisation of Firefox</hu>
    <id>Ukrainian localisation of Firefox</id>
@@ -54,8 +55,8 @@ Ukrainian_Firefox
    <ro>Ukrainian localisation of Firefox</ro>
    <ru>Украинская локализация Firefox</ru>
    <sk>Ukrainian localisation of Firefox</sk>
-   <sl>Ukrainian localisation of Firefox</sl>
-   <sq>Ukrainian localisation of Firefox</sq>
+   <sl>Ukrajinske krajevne nastavitve za Firefox</sl>
+   <sq>Përkthimi i Firefox-it në ukrainisht</sq>
    <sr>Ukrainian localisation of Firefox</sr>
    <sv>Ukrainsk lokalisering av Firefox</sv>
    <th>Ukrainian localisation ของ Firefox</th>
