@@ -28,11 +28,12 @@ Vietnamese_LO_Latest_main
    <fa>Vietnamese Language Meta-Package for LibreOffice</fa>
    <fil_PH>Vietnamese Language Meta-Package for LibreOffice</fil_PH>
    <fi>Vietnamilainen kielipaketti LibreOffice:lle</fi>
-   <fr_BE>Vietnamese Language Meta-Package for LibreOffice</fr_BE>
+   <fr_BE>Méta-paquet langue vietnamienne pour LibreOffice</fr_BE>
    <fr>Méta-paquet langue vietnamienne pour LibreOffice</fr>
    <gl_ES>Vietnamita Meta-paquete de Idioma para LibreOffice</gl_ES>
+   <gu>Vietnamese Language Meta-Package for LibreOffice</gu>
    <he_IL>Vietnamese Language Meta-Package for LibreOffice</he_IL>
-   <hi>Vietnamese Language Meta-Package for LibreOffice</hi>
+   <hi>लिब्रे-ऑफिस हेतु वियतनामी भाषा मेटा-पैकेज</hi>
    <hr>Vietnamese Language Meta-Package for LibreOffice</hr>
    <hu>Vietnamese Language Meta-Package for LibreOffice</hu>
    <id>Vietnamese Language Meta-Package for LibreOffice</id>
@@ -55,7 +56,7 @@ Vietnamese_LO_Latest_main
    <ru>Vietnamese Language Meta-Package for LibreOffice</ru>
    <sk>Vietnamese Language Meta-Package for LibreOffice</sk>
    <sl>Vietnamski jezikovni meta-paket za LibreOffice</sl>
-   <sq>Vietnamese Language Meta-Package for LibreOffice</sq>
+   <sq>Meta-Paketë gjuhësore për LibreOffice-in në vietnamisht</sq>
    <sr>Vietnamese Language Meta-Package for LibreOffice</sr>
    <sv>Vietnamesiskt Språk Meta-Paket för LibreOffice</sv>
    <th>Meta-Package ภาษา Vietnamese สำหรับ LibreOffice</th>
