@@ -42,7 +42,6 @@ Vietnamese_LO_full
    <ja>LibreOffice用のベトナム語メタパッケージ</ja>
    <kk>Vietnamese Language Meta-Package for LibreOffice</kk>
    <ko>Vietnamese Language Meta-Package for LibreOffice</ko>
-   <ku>Vietnamese Language Meta-Package for LibreOffice</ku>
    <lt>Vietnamese Language Meta-Package for LibreOffice</lt>
    <mk>Vietnamese Language Meta-Package for LibreOffice</mk>
    <mr>Vietnamese Language Meta-Package for LibreOffice</mr>
@@ -50,7 +49,6 @@ Vietnamese_LO_full
    <nb>Vietnamesisk språkpakke for LibreOffice</nb>
    <nl_BE>Vietnamese Language Meta-Package for LibreOffice</nl_BE>
    <nl>Vietnamese Taal Meta-Pakket voor LibreOffice</nl>
-   <or>Vietnamese Language Meta-Package for LibreOffice</or>
    <pl>Wietnamski meta-pakiet językowy dla LibreOffice</pl>
    <pt_BR>Vietnamita Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Vietnamita Meta-Pacote de Idioma para LibreOffice</pt>
@@ -58,7 +56,6 @@ Vietnamese_LO_full
    <ru>Vietnamese Language Meta-Package for LibreOffice</ru>
    <sk>Vietnamese Language Meta-Package for LibreOffice</sk>
    <sl>Vietnamski jezikovni meta-paket za LibreOffice</sl>
-   <so>Vietnamese Language Meta-Package for LibreOffice</so>
    <sq>Meta-Paketë gjuhësore për LibreOffice-in në vietnamisht</sq>
    <sr>Vietnamese Language Meta-Package for LibreOffice</sr>
    <sv>Vietnamesiskt Språk Meta-Paket för LibreOffice</sv>
