@@ -42,7 +42,6 @@ Welsh_LO_Latest_full
    <ja>LibreOffice用 ウェールズ語メタパッケージ</ja>
    <kk>Welsh Language Meta-Package for LibreOffice</kk>
    <ko>Welsh Language Meta-Package for LibreOffice</ko>
-   <ku>Welsh Language Meta-Package for LibreOffice</ku>
    <lt>Welsh Language Meta-Package for LibreOffice</lt>
    <mk>Welsh Language Meta-Package for LibreOffice</mk>
    <mr>Welsh Language Meta-Package for LibreOffice</mr>
@@ -50,7 +49,6 @@ Welsh_LO_Latest_full
    <nb>Walisisk språkpakke for LibreOffice</nb>
    <nl_BE>Welsh Language Meta-Package for LibreOffice</nl_BE>
    <nl>Welsh Taal Meta-Pakket voor LibreOffice</nl>
-   <or>Welsh Language Meta-Package for LibreOffice</or>
    <pl>Walijski meta-pakiet językowy dla LibreOffice</pl>
    <pt_BR>Galês Pacote de Idioma para o LibreOffice</pt_BR>
    <pt>Galês Meta-Pacote de Idioma para LibreOffice</pt>
@@ -58,7 +56,6 @@ Welsh_LO_Latest_full
    <ru>Welsh Language Meta-Package for LibreOffice</ru>
    <sk>Welsh Language Meta-Package for LibreOffice</sk>
    <sl>Velški jezikovni meta-paket za LibreOffice</sl>
-   <so>Welsh Language Meta-Package for LibreOffice</so>
    <sq>Meta-Paketë gjuhësore për LibreOffice-in në uellsisht</sq>
    <sr>Welsh Language Meta-Package for LibreOffice</sr>
    <sv>Walesiska Språk Meta-Paket för LibreOffice</sv>
