@@ -28,11 +28,12 @@ Zulu_LO_full
    <fa>Zulu Language Meta-Package for LibreOffice</fa>
    <fil_PH>Zulu Language Meta-Package for LibreOffice</fil_PH>
    <fi>Zulunkielinen kielipaketti LibreOffice:lle</fi>
-   <fr_BE>Zulu Language Meta-Package for LibreOffice</fr_BE>
+   <fr_BE>Meta-Paquet de langue Zoulou pour LibreOffice</fr_BE>
    <fr>Meta-Paquet de langue Zoulou pour LibreOffice</fr>
    <gl_ES>Zulú Meta-paquete de Idioma para LibreOffice</gl_ES>
+   <gu>Zulu Language Meta-Package for LibreOffice</gu>
    <he_IL>Zulu Language Meta-Package for LibreOffice</he_IL>
-   <hi>Zulu Language Meta-Package for LibreOffice</hi>
+   <hi>लिब्रे-ऑफिस हेतु ज़ुलु भाषा मेटा-पैकेज</hi>
    <hr>Zulu Language Meta-Package for LibreOffice</hr>
    <hu>Zulu Language Meta-Package for LibreOffice</hu>
    <id>Zulu Language Meta-Package for LibreOffice</id>
@@ -55,7 +56,7 @@ Zulu_LO_full
    <ru>Zulu Language Meta-Package for LibreOffice</ru>
    <sk>Zulu Language Meta-Package for LibreOffice</sk>
    <sl>Zulujski jezikovni meta-paket za LibreOffice</sl>
-   <sq>Zulu Language Meta-Package for LibreOffice</sq>
+   <sq>Meta-Paketë gjuhësore për LibreOffice-in në zulu</sq>
    <sr>Zulu Language Meta-Package for LibreOffice</sr>
    <sv>Zulu Språk Meta-Paket för LibreOffice</sv>
    <th>Meta-Package ภาษา Zulu สำหรับ LibreOffice</th>
