@@ -28,12 +28,12 @@ Claws-Mail
    <fa>Claws Mail lightweight email client</fa>
    <fil_PH>Claws Mail lightweight email client</fil_PH>
    <fi>Claws Mail on keveä sähköposti-asiakasohjelma</fi>
-   <fr_BE>Claws Mail lightweight email client</fr_BE>
+   <fr_BE>Client mail léger Claws Mail</fr_BE>
    <fr>Client mail léger Claws Mail</fr>
    <gl_ES>Cliente de correo-electrónico simple e lixiero</gl_ES>
    <gu>Claws Mail lightweight email client</gu>
    <he_IL>Claws Mail lightweight email client</he_IL>
-   <hi>Claws Mail lightweight email client</hi>
+   <hi>Claws Mail सरल ईमेल साधन</hi>
    <hr>Claws Mail lightweight email client</hr>
    <hu>Claws Mail lightweight email client</hu>
    <id>Claws Mail lightweight email client</id>
@@ -56,7 +56,7 @@ Claws-Mail
    <ru>Легковесный e-mail клиент</ru>
    <sk>Claws Mail lightweight email client</sk>
    <sl>Lahek poštni odjemalec Clwas Mail</sl>
-   <sq>Claws Mail lightweight email client</sq>
+   <sq>Klienti email i peshës së lehtë Claws Mail</sq>
    <sr>Claws Mail lightweight email client</sr>
    <sv>Claws Mail lättvikts E-mejl klient</sv>
    <th>Claws โปรแกรมอีเมลน้ำหนักเบา</th>
