@@ -31,8 +31,9 @@ Firefox
    <fr_BE>La dernière version de Firefox</fr_BE>
    <fr>La dernière version de Firefox</fr>
    <gl_ES>Versión máis recente do Firefox</gl_ES>
+   <gu>Latest Firefox</gu>
    <he_IL>Latest Firefox</he_IL>
-   <hi>Latest Firefox</hi>
+   <hi>फायरफॉक्स का नवीनतम संस्करण</hi>
    <hr>Latest Firefox</hr>
    <hu>Latest Firefox</hu>
    <id>Latest Firefox</id>
@@ -55,7 +56,7 @@ Firefox
    <ru>Браузер Firefox последней версии</ru>
    <sk>Posledný Firefox</sk>
    <sl>Zadnja različica Firefox-a</sl>
-   <sq>Latest Firefox</sq>
+   <sq>Firefox më i ri</sq>
    <sr>Latest Firefox</sr>
    <sv>Senaste Firefox</sv>
    <th>Firefox รุ่นล่าสุด</th>
