@@ -15,7 +15,7 @@ fvwm_crystal
    <be>fvwm-crystal window manager</be>
    <bg>fvwm-crystal window manager</bg>
    <bn>fvwm-crystal window manager</bn>
-   <ca>fvwm-crystal window manager</ca>
+   <ca>Gestor de finestres fvwm-crystal</ca>
    <cs>fvwm-crystal window manager</cs>
    <da>fvwm-crystal window manager</da>
    <de>transparenter “Chrystal” Stil für die Fensterverwaltung “FVWM”</de>
@@ -28,12 +28,12 @@ fvwm_crystal
    <fa>fvwm-crystal window manager</fa>
    <fil_PH>fvwm-crystal window manager</fil_PH>
    <fi>fvwm-crystal window manager</fi>
-   <fr_BE>fvwm-crystal window manager</fr_BE>
+   <fr_BE>fvwm-crystal gestionnaire de fenêtres</fr_BE>
    <fr>fvwm-crystal gestionnaire de fenêtres</fr>
    <gl_ES>fvwm-crystal window manager</gl_ES>
    <gu>fvwm-crystal window manager</gu>
    <he_IL>fvwm-crystal window manager</he_IL>
-   <hi>fvwm-crystal window manager</hi>
+   <hi>एफवी-डब्लूएम क्रिस्टल सरल विंडो प्रबंधक</hi>
    <hr>fvwm-crystal window manager</hr>
    <hu>fvwm-crystal window manager</hu>
    <id>fvwm-crystal window manager</id>
@@ -50,13 +50,13 @@ fvwm_crystal
    <nl_BE>fvwm-crystal window manager</nl_BE>
    <nl>fvwm-crystal window manager</nl>
    <pl>fvwm-crystal window manager</pl>
-   <pt_BR>fvwm-crystal gerenciador de janela</pt_BR>
+   <pt_BR>fvwm-crystal gerenciador de janelas</pt_BR>
    <pt>Gestor de janelas fvwm-crystal</pt>
    <ro>fvwm-crystal window manager</ro>
    <ru>fvwm-crystal window manager</ru>
    <sk>fvwm-crystal window manager</sk>
-   <sl>fvwm-crystal window manager</sl>
-   <sq>fvwm-crystal window manager</sq>
+   <sl>fvwm-crystal okenski upravljalnik</sl>
+   <sq>Përgjegjësi fvwm-crystal i dritareve</sq>
    <sr>fvwm-crystal window manager</sr>
    <sv>fvwm-crystal fönsterhanterare</sv>
    <th>fvwm-crystal window manager</th>
