@@ -42,7 +42,6 @@ Latest GIMP Basic
    <ja>高度な画像エディター - GIMPのみインストール</ja>
    <kk>advanced picture editor - installs GIMP only</kk>
    <ko>advanced picture editor - installs GIMP only</ko>
-   <ku>advanced picture editor - installs GIMP only</ku>
    <lt>išplėstinis paveikslų redaktorius - įdiegia tik GIMP</lt>
    <mk>advanced picture editor - installs GIMP only</mk>
    <mr>advanced picture editor - installs GIMP only</mr>
@@ -50,7 +49,6 @@ Latest GIMP Basic
    <nb>avansert bilderedigering – installerer kun GIMP</nb>
    <nl_BE>advanced picture editor - installs GIMP only</nl_BE>
    <nl>geavanceerde foto-editor - installeert alleen GIMP</nl>
-   <or>advanced picture editor - installs GIMP only</or>
    <pl>zaawansowany edytor grafiki i zdjęć - instaluje tylko program GIMP</pl>
    <pt_BR>Editor de imagem avançado - instala apenas o GIMP</pt_BR>
    <pt>Editor de imagem avançado - instala apenas o GIMP</pt>
@@ -58,7 +56,6 @@ Latest GIMP Basic
    <ru>Продвинутый графический редактор - установка только GIMP</ru>
    <sk>advanced picture editor - installs GIMP only</sk>
    <sl>napredni urejevalnik slik - namesti le GIMP</sl>
-   <so>advanced picture editor - installs GIMP only</so>
    <sq>Një klient FTP me shumë rrjedha</sq>
    <sr>advanced picture editor - installs GIMP only</sr>
    <sv>avancerad bildredigerare - installerar enbart GIMP</sv>
@@ -78,7 +75,7 @@ all
 <screenshot>none</screenshot>
 
 <preinstall>
-sudo apt-key adv --keyserver hkp://keyserver.ubuntu.com:80 --recv-keys E1C726CD
+sudo apt-key adv --keyserver hkp://keyserver.ubuntu.com:80 --recv-keys 276ECD5CEF864D8F
 echo "deb http://mxrepo.com/mx/repo/ buster main non-free">/etc/apt/sources.list.d/pitemp1.list
 sleep .1
 echo "deb http://mxrepo.com/mx/testrepo/ buster test ">/etc/apt/sources.list.d/pitemp.list
