@@ -28,11 +28,12 @@ Simple Card Games
    <fa>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</fa>
    <fil_PH>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</fil_PH>
    <fi>Yksinkertaisia kortti- ja pulmapelejä työpöydälle (pasianssi, hertta, miinaharava, jne)</fi>
-   <fr_BE>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</fr_BE>
+   <fr_BE>Jeux de cartes et puzzles (solitaire, la dame de pique, mines, etc)</fr_BE>
    <fr>Jeux de cartes et puzzles (solitaire, la dame de pique, mines, etc)</fr>
    <gl_ES>Xogos simples (solitario, corazóns, minas, etc)</gl_ES>
+   <gu>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</gu>
    <he_IL>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</he_IL>
-   <hi>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</hi>
+   <hi>सरल डेस्कटॉप कार्ड व पहेली खेल (सॉलिटेयर, हर्ट्स, माइंस इत्यादि)</hi>
    <hr>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</hr>
    <hu>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</hu>
    <id>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</id>
@@ -55,7 +56,7 @@ Simple Card Games
    <ru>Простые карточные игры и головоломки (солитер, червы, сапёр, и т.д.)</ru>
    <sk>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</sk>
    <sl>Preprosta namizna igra s kartami in miselne igre )solitaire, srca, mine, itd.)</sl>
-   <sq>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</sq>
+   <sq>Instalim shumë minimal i Gnome-s</sq>
    <sr>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</sr>
    <sv>Enkla skrivbords kort och pusselspel (patiens, hjärter, minor, etc)</sv>
    <th>Simple Desktop Card and Puzzle Games (solitare, hearts, mines, etc)</th>
