@@ -15,7 +15,7 @@ Network Manager
    <be>System network service to manage network devices and connections</be>
    <bg>System network service to manage network devices and connections</bg>
    <bn>System network service to manage network devices and connections</bn>
-   <ca>System network service to manage network devices and connections</ca>
+   <ca>Servei de xarxa del sistema per gestionar dispositius i connexions</ca>
    <cs>System network service to manage network devices and connections</cs>
    <da>System network service to manage network devices and connections</da>
    <de>Netzwerk-Dienstprogramm für die Verwaltung von Netzwerkgeräten und Verbindungen</de>
@@ -28,12 +28,12 @@ Network Manager
    <fa>System network service to manage network devices and connections</fa>
    <fil_PH>System network service to manage network devices and connections</fil_PH>
    <fi>Järjestelmän verkkopalvelu verkon laitteiden ja yhteyksien hallintaan</fi>
-   <fr_BE>System network service to manage network devices and connections</fr_BE>
+   <fr_BE>Service réseau du système pour gérer les périphériques et les connexions du réseau</fr_BE>
    <fr>Service réseau du système pour gérer les périphériques et les connexions du réseau</fr>
    <gl_ES>System network service to manage network devices and connections</gl_ES>
    <gu>System network service to manage network devices and connections</gu>
    <he_IL>System network service to manage network devices and connections</he_IL>
-   <hi>System network service to manage network devices and connections</hi>
+   <hi>नेटवर्क उपकरणों व कनेक्शन के प्रबंधन हेतु सिस्टम नेटवर्क सेवा</hi>
    <hr>System network service to manage network devices and connections</hr>
    <hu>System network service to manage network devices and connections</hu>
    <id>System network service to manage network devices and connections</id>
@@ -56,11 +56,11 @@ Network Manager
    <ru>System network service to manage network devices and connections</ru>
    <sk>System network service to manage network devices and connections</sk>
    <sl>Sistemska omrežna storitev za upravljanje omrežnih naprav in povezav</sl>
-   <sq>System network service to manage network devices and connections</sq>
+   <sq>Shërbim rrjeti sistemi për të administruar pajisje dhe lidhje rrjeti</sq>
    <sr>System network service to manage network devices and connections</sr>
    <sv>System-nätverks service för att hantera nätverksenheter och anslutningar</sv>
    <th>System network service to manage network devices and connections</th>
-   <tr>System network service to manage network devices and connections</tr>
+   <tr>Ağ aygıtlarını ve bağlantılarını yönetmek için sistem ağ hizmeti</tr>
    <uk>System network service to manage network devices and connections</uk>
    <vi>System network service to manage network devices and connections</vi>
    <zh_CN>System network service to manage network devices and connections</zh_CN>
