@@ -15,29 +15,30 @@ Remmina
    <be>Remote desktop client written in GTK+</be>
    <bg>Remote desktop client written in GTK+</bg>
    <bn>Remote desktop client written in GTK+</bn>
-   <ca>Remote desktop client written in GTK+</ca>
+   <ca>Client d'escriptori remot escrit en GTK+</ca>
    <cs>Remote desktop client written in GTK+</cs>
    <da>Remote desktop client written in GTK+</da>
    <de>Client für Fernzugriff auf den Desktop (verwendet die GTK Programmbibliothek)</de>
    <el>Πελάτης απομακρυσμένης επιφάνειας εργασίας γραμμένο σε GTK+</el>
    <en>Remote desktop client written in GTK+</en>
-   <es_ES>Remote desktop client written in GTK+</es_ES>
+   <es_ES>Cliente de escritorio remoto escrito en GTK+</es_ES>
    <es>Cliente de escritorio remoto escrito en GTK+</es>
    <et>Remote desktop client written in GTK+</et>
    <eu>Remote desktop client written in GTK+</eu>
    <fa>Remote desktop client written in GTK+</fa>
    <fil_PH>Remote desktop client written in GTK+</fil_PH>
-   <fi>Remote desktop client written in GTK+</fi>
+   <fi>GTK+-pohjainen etätyöpöydänhallinta</fi>
    <fr_BE>Client de bureau à distance écrit en GTK+</fr_BE>
    <fr>Client de bureau à distance écrit en GTK+</fr>
    <gl_ES>Remote desktop client written in GTK+</gl_ES>
+   <gu>Remote desktop client written in GTK+</gu>
    <he_IL>Remote desktop client written in GTK+</he_IL>
-   <hi>Remote desktop client written in GTK+</hi>
+   <hi>जीटीके+ में रचित दूरस्थ डेस्कटॉप साधन</hi>
    <hr>Remote desktop client written in GTK+</hr>
    <hu>Remote desktop client written in GTK+</hu>
    <id>Remote desktop client written in GTK+</id>
    <is>Remote desktop client written in GTK+</is>
-   <it>Remote desktop client written in GTK+</it>
+   <it>Client per desktop remoto scritto in GTK +</it>
    <ja>GTK+で作られたリモートデスクトップ・クライアント</ja>
    <kk>Remote desktop client written in GTK+</kk>
    <ko>Remote desktop client written in GTK+</ko>
@@ -50,16 +51,16 @@ Remmina
    <nl>Remote desktop client written in GTK+</nl>
    <pl>Remote desktop client written in GTK+</pl>
    <pt_BR>Cliente de área de trabalho remoto escrito em GTK+</pt_BR>
-   <pt>Remote desktop client written in GTK+</pt>
+   <pt>Cliente para desktop remoto escrito em GTK+</pt>
    <ro>Remote desktop client written in GTK+</ro>
    <ru>Remote desktop client written in GTK+</ru>
    <sk>Remote desktop client written in GTK+</sk>
-   <sl>Remote desktop client written in GTK+</sl>
-   <sq>Remote desktop client written in GTK+</sq>
+   <sl>Odejamlec za oddaljeni dostop napisan v GTK+</sl>
+   <sq>Klient desktopi të largët, shkruar në GTK+</sq>
    <sr>Remote desktop client written in GTK+</sr>
    <sv>Fjärrskrivbords-klient skriven i GTK+</sv>
    <th>Remote desktop client written in GTK+</th>
-   <tr>Remote desktop client written in GTK+</tr>
+   <tr>GTK+ ile yazılmış uzak masaüstü istemcisi</tr>
    <uk>Remote desktop client written in GTK+</uk>
    <vi>Remote desktop client written in GTK+</vi>
    <zh_CN>Remote desktop client written in GTK+</zh_CN>
