@@ -15,7 +15,7 @@ Repo Manager
    <be>GUI for setting antiX and Debian repos</be>
    <bg>GUI for setting antiX and Debian repos</bg>
    <bn>GUI for setting antiX and Debian repos</bn>
-   <ca>GUI for setting antiX and Debian repos</ca>
+   <ca>IGU per definir els dipòsits d'antiX i Debian</ca>
    <cs>GUI for setting antiX and Debian repos</cs>
    <da>GUI for setting antiX and Debian repos</da>
    <de>Graphische Oberfläche zur Festlegung der antiX- und Debian-Repositorien.</de>
@@ -28,12 +28,12 @@ Repo Manager
    <fa>GUI for setting antiX and Debian repos</fa>
    <fil_PH>GUI for setting antiX and Debian repos</fil_PH>
    <fi>Käyttöliittymä antiX- ja Debian-pakettihakemistojen asettamiseen</fi>
-   <fr_BE>GUI for setting antiX and Debian repos</fr_BE>
+   <fr_BE>Interface graphique pour configurer les dépôts antiX et Debian</fr_BE>
    <fr>Interface graphique pour configurer les dépôts antiX et Debian</fr>
    <gl_ES>GUI for setting antiX and Debian repos</gl_ES>
    <gu>GUI for setting antiX and Debian repos</gu>
    <he_IL>GUI for setting antiX and Debian repos</he_IL>
-   <hi>GUI for setting antiX and Debian repos</hi>
+   <hi>एंटी-एक्स व डेबियन पैकेज-संग्रह सेट करने हेतु ग्राफ़िकल अंतरफलक</hi>
    <hr>GUI for setting antiX and Debian repos</hr>
    <hu>GUI for setting antiX and Debian repos</hu>
    <id>GUI for setting antiX and Debian repos</id>
@@ -55,12 +55,12 @@ Repo Manager
    <ro>GUI for setting antiX and Debian repos</ro>
    <ru>GUI for setting antiX and Debian repos</ru>
    <sk>GUI for setting antiX and Debian repos</sk>
-   <sl>GUI for setting antiX and Debian repos</sl>
-   <sq>GUI for setting antiX and Debian repos</sq>
+   <sl>Grafični vmesnik za nastavljanje antiX in Debian repozitorijev</sl>
+   <sq>GUI për ujdisje deposh antiX dhe Debian</sq>
    <sr>GUI for setting antiX and Debian repos</sr>
    <sv>Grafiskt användargränssnitt för att ställa in antiX och Debian förråd</sv>
    <th>GUI for setting antiX and Debian repos</th>
-   <tr>GUI for setting antiX and Debian repos</tr>
+   <tr>antiX ve Debian depolarını ayarlamak için grafik arayüz</tr>
    <uk>GUI for setting antiX and Debian repos</uk>
    <vi>GUI for setting antiX and Debian repos</vi>
    <zh_CN>GUI for setting antiX and Debian repos</zh_CN>
