@@ -28,12 +28,12 @@ ROXFiler
    <fa>a fast and powerful graphical file manager</fa>
    <fil_PH>a fast and powerful graphical file manager</fil_PH>
    <fi>nopea ja tehokas graafinen tiedostonhallinta</fi>
-   <fr_BE>a fast and powerful graphical file manager</fr_BE>
+   <fr_BE>Un gestionnaire de fichiers rapide et puissant</fr_BE>
    <fr>Un gestionnaire de fichiers rapide et puissant</fr>
    <gl_ES>Xestor de ficheiros gráfico, rápido e poderoso</gl_ES>
    <gu>a fast and powerful graphical file manager</gu>
    <he_IL>a fast and powerful graphical file manager</he_IL>
-   <hi>a fast and powerful graphical file manager</hi>
+   <hi>तीव्र व सशक्त ग्राफ़िकल फाइल प्रबंधक</hi>
    <hr>a fast and powerful graphical file manager</hr>
    <hu>a fast and powerful graphical file manager</hu>
    <id>a fast and powerful graphical file manager</id>
@@ -56,7 +56,7 @@ ROXFiler
    <ru>Быстрый и многофункциональный файловый менеджер</ru>
    <sk>a fast and powerful graphical file manager</sk>
    <sl>Hiter in zmogljiv grafični upravljalnik datotek</sl>
-   <sq>a fast and powerful graphical file manager</sq>
+   <sq>Një përgjegjës grafik kartelash, i shpejtë dhe i fuqishëm</sq>
    <sr>a fast and powerful graphical file manager</sr>
    <sv>en snabb och kraftfull grafisk filhanterare</sv>
    <th>โปรแกรมจัดการไฟล์แบบกราฟิกที่รวดเร็วและทรงพลัง</th>
