@@ -15,7 +15,7 @@ Skippy-XD
    <be>Full-screen task-switcher for X11</be>
    <bg>Full-screen task-switcher for X11</bg>
    <bn>Full-screen task-switcher for X11</bn>
-   <ca>Full-screen task-switcher for X11</ca>
+   <ca>Canviador de tasques en pantalla sencera per X11</ca>
    <cs>Full-screen task-switcher for X11</cs>
    <da>Full-screen task-switcher for X11</da>
    <de>Vollbild-Programmumschalter für das X Window System (X11)</de>
@@ -28,12 +28,12 @@ Skippy-XD
    <fa>Full-screen task-switcher for X11</fa>
    <fil_PH>Full-screen task-switcher for X11</fil_PH>
    <fi>Full-screen task-switcher for X11</fi>
-   <fr_BE>Full-screen task-switcher for X11</fr_BE>
+   <fr_BE>Sélecteur de tâches en plein écran pour X11</fr_BE>
    <fr>Sélecteur de tâches en plein écran pour X11</fr>
    <gl_ES>Full-screen task-switcher for X11</gl_ES>
    <gu>Full-screen task-switcher for X11</gu>
    <he_IL>Full-screen task-switcher for X11</he_IL>
-   <hi>Full-screen task-switcher for X11</hi>
+   <hi>X11 हेतु पूर्ण-स्क्रीन कार्य-परिवर्तन साधन</hi>
    <hr>Full-screen task-switcher for X11</hr>
    <hu>Full-screen task-switcher for X11</hu>
    <id>Full-screen task-switcher for X11</id>
@@ -55,12 +55,12 @@ Skippy-XD
    <ro>Full-screen task-switcher for X11</ro>
    <ru>Full-screen task-switcher for X11</ru>
    <sk>Full-screen task-switcher for X11</sk>
-   <sl>Full-screen task-switcher for X11</sl>
-   <sq>Full-screen task-switcher for X11</sq>
+   <sl>Celozaslonski preklopnik optravil za X11</sl>
+   <sq>Këmbyes punësh për X11, sa krejt ekrani</sq>
    <sr>Full-screen task-switcher for X11</sr>
    <sv>Fullskärms aktivitetsväxlare för X11</sv>
    <th>Full-screen task-switcher for X11</th>
-   <tr>Full-screen task-switcher for X11</tr>
+   <tr>X11 için tam ekran görev değiştirici</tr>
    <uk>Full-screen task-switcher for X11</uk>
    <vi>Full-screen task-switcher for X11</vi>
    <zh_CN>Full-screen task-switcher for X11</zh_CN>
