@@ -28,11 +28,12 @@ SuperTux
    <fa>Mario style platform game w/ Tux</fa>
    <fil_PH>Mario style platform game w/ Tux</fil_PH>
    <fi>Super Mario- tyylinen tasohyppely jossa pääosassa on Tux</fi>
-   <fr_BE>Mario style platform game w/ Tux</fr_BE>
+   <fr_BE>Jeu de plate-formes de style Mario, mais avec Tux comme héros</fr_BE>
    <fr>Jeu de plate-formes de style Mario, mais avec Tux comme héros</fr>
    <gl_ES>Plataforma de xogo do tipo Mario, con Tux</gl_ES>
+   <gu>Mario style platform game w/ Tux</gu>
    <he_IL>Mario style platform game w/ Tux</he_IL>
-   <hi>Mario style platform game w/ Tux</hi>
+   <hi>मारिओ स्टाइल प्लेटफार्म खेल, टक्स युक्त</hi>
    <hr>Mario style platform game w/ Tux</hr>
    <hu>Mario style platform game w/ Tux</hu>
    <id>Mario style platform game w/ Tux</id>
@@ -55,7 +56,7 @@ SuperTux
    <ru>Игра-платформер в духе Mario</ru>
    <sk>Mario style platform game w/ Tux</sk>
    <sl>Platformska igra tipa Mario z Tux</sl>
-   <sq>Mario style platform game w/ Tux</sq>
+   <sq>Lojë platforme në stil Mario me Tux-in</sq>
    <sr>Mario style platform game w/ Tux</sr>
    <sv>Plattformsspel i Mariostil med Tux</sv>
    <th>Mario style platform game w/ Tux</th>
